# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component IdentityMapping

.. autofunction:: IdentityMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def IdentityMapping(self, **kwargs):
    """
    Special case of mapping where the child points are the same as the parent points
Special case of mapping where the child points are the same as the parent points
Special case of mapping where the child points are the same as the parent points



    """
    params = dict()
    return "IdentityMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CorotationalMeshMapping

.. autofunction:: CorotationalMeshMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CorotationalMeshMapping(self, **kwargs):
    """
    Rigidly aligns positions to rest positions for each element



    """
    params = dict()
    return "CorotationalMeshMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TaitSurfacePressureForceField

.. autofunction:: TaitSurfacePressureForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TaitSurfacePressureForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, p0=None, B=None, gamma=None, injectedVolume=None, maxInjectionRate=None, initialVolume=None, currentInjectedVolume=None, v0=None, currentVolume=None, currentPressure=None, currentStiffness=None, pressureTriangles=None, initialSurfaceArea=None, currentSurfaceArea=None, drawForceScale=None, drawForceColor=None, volumeAfterTC=None, surfaceAreaAfterTC=None, **kwargs):
    """
    This component computes the volume enclosed by a surface mesh and apply a pressure force following Tait's equation: $P = P_0 - B((V/V_0)^\gamma - 1)$.
This ForceField can be used to apply :
 * a constant pressure (set $B=0$ and use $P_0$)
 * an ideal gas pressure (set $\gamma=1$ and use $B$)
 * a pressure from water (set $\gamma=7$ and use $B$)


    :param name: object name  Default value: TaitSurfacePressureForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param p0: IN: Rest pressure when V = V0  Default value: 0.0

    :param B: IN: Bulk modulus (resistance to uniform compression)  Default value: 0.0

    :param gamma: IN: Bulk modulus (resistance to uniform compression)  Default value: 0.0

    :param injectedVolume: IN: Injected (or extracted) volume since the start of the simulation  Default value: 0.0

    :param maxInjectionRate: IN: Maximum injection rate (volume per second)  Default value: 1000.0

    :param initialVolume: OUT: Initial volume, as computed from the surface rest position  Default value: 0.0

    :param currentInjectedVolume: OUT: Current injected (or extracted) volume (taking into account maxInjectionRate)  Default value: 0.0

    :param v0: OUT: Rest volume (as computed from initialVolume + injectedVolume)  Default value: 0.0

    :param currentVolume: OUT: Current volume, as computed from the last surface position  Default value: 0.0

    :param currentPressure: OUT: Current pressure, as computed from the last surface position  Default value: 0.0

    :param currentStiffness: OUT: dP/dV at current volume and pressure  Default value: 0.0

    :param pressureTriangles: OUT: list of triangles where a pressure is applied (mesh triangles + tesselated quads)  Default value: []

    :param initialSurfaceArea: OUT: Initial surface area, as computed from the surface rest position  Default value: 0.0

    :param currentSurfaceArea: OUT: Current surface area, as computed from the last surface position  Default value: 0.0

    :param drawForceScale: DEBUG: scale used to render force vectors  Default value: 0.001

    :param drawForceColor: DEBUG: color used to render force vectors  Default value: [[0.0, 1.0, 1.0, 1.0]]

    :param volumeAfterTC: OUT: Volume after a topology change  Default value: 0.0

    :param surfaceAreaAfterTC: OUT: Surface area after a topology change  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, p0=p0, B=B, gamma=gamma, injectedVolume=injectedVolume, maxInjectionRate=maxInjectionRate, initialVolume=initialVolume, currentInjectedVolume=currentInjectedVolume, v0=v0, currentVolume=currentVolume, currentPressure=currentPressure, currentStiffness=currentStiffness, pressureTriangles=pressureTriangles, initialSurfaceArea=initialSurfaceArea, currentSurfaceArea=currentSurfaceArea, drawForceScale=drawForceScale, drawForceColor=drawForceColor, volumeAfterTC=volumeAfterTC, surfaceAreaAfterTC=surfaceAreaAfterTC)
    return "TaitSurfacePressureForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component RecordedCamera

.. autofunction:: RecordedCamera

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def RecordedCamera(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, position=None, orientation=None, lookAt=None, distance=None, fieldOfView=None, zNear=None, zFar=None, computeZClip=None, minBBox=None, maxBBox=None, widthViewport=None, heightViewport=None, projectionType=None, activated=None, fixedLookAt=None, modelViewMatrix=None, projectionMatrix=None, zoomSpeed=None, panSpeed=None, pivot=None, startTime=None, endTime=None, rotationMode=None, translationMode=None, navigationMode=None, rotationSpeed=None, rotationCenter=None, rotationStartPoint=None, rotationLookAt=None, rotationAxis=None, cameraUp=None, drawRotation=None, drawTranslation=None, cameraPositions=None, cameraOrientations=None, **kwargs):
    """
    A camera that is moving along a predetermined path.


    :param name: object name  Default value: RecordedCamera

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param position: Camera's position  Default value: [[0.0, 0.0, 0.0]]

    :param orientation: Camera's orientation  Default value: [[0.0, 0.0, 0.0, 1.0]]

    :param lookAt: Camera's look at  Default value: [[0.0, 0.0, 0.0]]

    :param distance: Distance between camera and look at  Default value: 0.0

    :param fieldOfView: Camera's FOV  Default value: 45.0

    :param zNear: Camera's zNear  Default value: 0.01

    :param zFar: Camera's zFar  Default value: 100.0

    :param computeZClip: Compute Z clip planes (Near and Far) according to the bounding box  Default value: 1

    :param minBBox: minBBox  Default value: [[0.0, 0.0, 0.0]]

    :param maxBBox: maxBBox  Default value: [[1.0, 1.0, 1.0]]

    :param widthViewport: widthViewport  Default value: 800

    :param heightViewport: heightViewport  Default value: 600

    :param projectionType: Camera Type (0 = Perspective, 1 = Orthographic)  Default value: Perspective

    :param activated: Camera activated ?  Default value: 1

    :param fixedLookAt: keep the lookAt point always fixed  Default value: 0

    :param modelViewMatrix: ModelView Matrix  Default value: [[0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0]]

    :param projectionMatrix: Projection Matrix  Default value: [[0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0]]

    :param zoomSpeed: Zoom Speed  Default value: 250.0

    :param panSpeed: Pan Speed  Default value: 0.1

    :param pivot: Pivot (0 => Scene center, 1 => World Center  Default value: 0

    :param startTime: Time when the camera moves will start  Default value: 0.0

    :param endTime: Time when the camera moves will end (or loop)  Default value: 200.0

    :param rotationMode: If true, rotation will be performed  Default value: 0

    :param translationMode: If true, translation will be performed  Default value: 0

    :param navigationMode: If true, navigation will be performed  Default value: 0

    :param rotationSpeed: rotation Speed  Default value: 0.1

    :param rotationCenter: Rotation center coordinates  Default value: [[0.0, 0.0, 0.0]]

    :param rotationStartPoint: Rotation start position coordinates  Default value: [[0.0, 0.0, 0.0]]

    :param rotationLookAt: Position to be focused during rotation  Default value: [[0.0, 0.0, 0.0]]

    :param rotationAxis: Rotation axis  Default value: [[0.0, 1.0, 0.0]]

    :param cameraUp: Camera Up axis  Default value: [[0.0, 0.0, 0.0]]

    :param drawRotation: If true, will draw the rotation path  Default value: 0

    :param drawTranslation: If true, will draw the translation path  Default value: 0

    :param cameraPositions: Intermediate camera's positions  Default value: []

    :param cameraOrientations: Intermediate camera's orientations  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, position=position, orientation=orientation, lookAt=lookAt, distance=distance, fieldOfView=fieldOfView, zNear=zNear, zFar=zFar, computeZClip=computeZClip, minBBox=minBBox, maxBBox=maxBBox, widthViewport=widthViewport, heightViewport=heightViewport, projectionType=projectionType, activated=activated, fixedLookAt=fixedLookAt, modelViewMatrix=modelViewMatrix, projectionMatrix=projectionMatrix, zoomSpeed=zoomSpeed, panSpeed=panSpeed, pivot=pivot, startTime=startTime, endTime=endTime, rotationMode=rotationMode, translationMode=translationMode, navigationMode=navigationMode, rotationSpeed=rotationSpeed, rotationCenter=rotationCenter, rotationStartPoint=rotationStartPoint, rotationLookAt=rotationLookAt, rotationAxis=rotationAxis, cameraUp=cameraUp, drawRotation=drawRotation, drawTranslation=drawTranslation, cameraPositions=cameraPositions, cameraOrientations=cameraOrientations)
    return "RecordedCamera", params



# -*- coding: utf-8 -*-


"""
Module ProjectiveConstraintSet

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    ProjectivePressureConstraint

    PartialFixedConstraint

    ParabolicConstraint

    ProjectToPlaneConstraint

    FixedPlaneConstraint

    OscillatorConstraint

    PartialLinearMovementConstraint

    AffineMovementConstraint

    PointConstraint

    FixedConstraint

    LinearMovementConstraint

    PatchTestMovementConstraint

    ProjectToPointConstraint

    AttachConstraint

    ProjectDirectionConstraint

    PositionBasedDynamicsConstraint

    HermiteSplineConstraint

    LinearVelocityConstraint

    ProjectToLineConstraint



Content:
========

.. automodule::

    ProjectivePressureConstraint

    PartialFixedConstraint

    ParabolicConstraint

    ProjectToPlaneConstraint

    FixedPlaneConstraint

    OscillatorConstraint

    PartialLinearMovementConstraint

    AffineMovementConstraint

    PointConstraint

    FixedConstraint

    LinearMovementConstraint

    PatchTestMovementConstraint

    ProjectToPointConstraint

    AttachConstraint

    ProjectDirectionConstraint

    PositionBasedDynamicsConstraint

    HermiteSplineConstraint

    LinearVelocityConstraint

    ProjectToLineConstraint



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['ProjectivePressureConstraint', 'PartialFixedConstraint', 'ParabolicConstraint', 'ProjectToPlaneConstraint', 'FixedPlaneConstraint', 'OscillatorConstraint', 'PartialLinearMovementConstraint', 'AffineMovementConstraint', 'PointConstraint', 'FixedConstraint', 'LinearMovementConstraint', 'PatchTestMovementConstraint', 'ProjectToPointConstraint', 'AttachConstraint', 'ProjectDirectionConstraint', 'PositionBasedDynamicsConstraint', 'HermiteSplineConstraint', 'LinearVelocityConstraint', 'ProjectToLineConstraint']
class ProjectiveConstraintSet:
    from .ProjectivePressureConstraint import ProjectivePressureConstraint
    from .PartialFixedConstraint import PartialFixedConstraint
    from .ParabolicConstraint import ParabolicConstraint
    from .ProjectToPlaneConstraint import ProjectToPlaneConstraint
    from .FixedPlaneConstraint import FixedPlaneConstraint
    from .OscillatorConstraint import OscillatorConstraint
    from .PartialLinearMovementConstraint import PartialLinearMovementConstraint
    from .AffineMovementConstraint import AffineMovementConstraint
    from .PointConstraint import PointConstraint
    from .FixedConstraint import FixedConstraint
    from .LinearMovementConstraint import LinearMovementConstraint
    from .PatchTestMovementConstraint import PatchTestMovementConstraint
    from .ProjectToPointConstraint import ProjectToPointConstraint
    from .AttachConstraint import AttachConstraint
    from .ProjectDirectionConstraint import ProjectDirectionConstraint
    from .PositionBasedDynamicsConstraint import PositionBasedDynamicsConstraint
    from .HermiteSplineConstraint import HermiteSplineConstraint
    from .LinearVelocityConstraint import LinearVelocityConstraint
    from .ProjectToLineConstraint import ProjectToLineConstraint



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TransformPosition

.. autofunction:: TransformPosition

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TransformPosition(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, origin=None, input_position=None, output_position=None, normal=None, translation=None, rotation=None, scale=None, matrix=None, method=None, seedValue=None, maxRandomDisplacement=None, fixedIndices=None, filename=None, drawInput=None, drawOutput=None, pointSize=None, **kwargs):
    """
    Transform position of 3d points


    :param name: object name  Default value: TransformPosition

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param origin: A 3d point on the plane/Center of the scale  Default value: [[0.0, 0.0, 0.0]]

    :param input_position: input array of 3d points  Default value: []

    :param output_position: output array of 3d points projected on a plane  Default value: []

    :param normal: plane normal  Default value: [[0.0, 0.0, 0.0]]

    :param translation: translation vector   Default value: [[0.0, 0.0, 0.0]]

    :param rotation: rotation vector   Default value: [[0.0, 0.0, 0.0]]

    :param scale: scale factor  Default value: [[1.0, 1.0, 1.0]]

    :param matrix: 4x4 affine matrix  Default value: [[1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0]]

    :param method: transformation method either translation or scale or rotation or random or projectOnPlane  Default value: projectOnPlane

    :param seedValue: the seed value for the random generator  Default value: 0

    :param maxRandomDisplacement: the maximum displacement around initial position for the random transformation  Default value: 1.0

    :param fixedIndices: Indices of the entries that are not transformed  Default value: []

    :param filename: filename of an affine matrix. Supported extensions are: .trm, .tfm, .xfm and .txt(read as .xfm)  Default value: 

    :param drawInput: Draw input points  Default value: 0

    :param drawOutput: Draw output points  Default value: 0

    :param pointSize: Point size  Default value: 1.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, origin=origin, input_position=input_position, output_position=output_position, normal=normal, translation=translation, rotation=rotation, scale=scale, matrix=matrix, method=method, seedValue=seedValue, maxRandomDisplacement=maxRandomDisplacement, fixedIndices=fixedIndices, filename=filename, drawInput=drawInput, drawOutput=drawOutput, pointSize=pointSize)
    return "TransformPosition", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PlaneROI

.. autofunction:: PlaneROI

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PlaneROI(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, plane=None, position=None, edges=None, triangles=None, tetrahedra=None, computeEdges=None, computeTriangles=None, computeTetrahedra=None, indices=None, edgeIndices=None, triangleIndices=None, tetrahedronIndices=None, pointsInROI=None, edgesInROI=None, trianglesInROI=None, tetrahedraInROI=None, drawBoxes=None, drawPoints=None, drawEdges=None, drawTriangles=None, drawTetrahedra=None, drawSize=None, **kwargs):
    """
    Find the primitives inside a given plane


    :param name: object name  Default value: PlaneROI

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param plane: Plane defined by 3 points and a depth distance  Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]

    :param position: Rest position coordinates of the degrees of freedom  Default value: []

    :param edges: Edge Topology  Default value: []

    :param triangles: Triangle Topology  Default value: []

    :param tetrahedra: Tetrahedron Topology  Default value: []

    :param computeEdges: If true, will compute edge list and index list inside the ROI.  Default value: 1

    :param computeTriangles: If true, will compute triangle list and index list inside the ROI.  Default value: 1

    :param computeTetrahedra: If true, will compute tetrahedra list and index list inside the ROI.  Default value: 1

    :param indices: Indices of the points contained in the ROI  Default value: [[0]]

    :param edgeIndices: Indices of the edges contained in the ROI  Default value: []

    :param triangleIndices: Indices of the triangles contained in the ROI  Default value: []

    :param tetrahedronIndices: Indices of the tetrahedra contained in the ROI  Default value: []

    :param pointsInROI: Points contained in the ROI  Default value: []

    :param edgesInROI: Edges contained in the ROI  Default value: []

    :param trianglesInROI: Triangles contained in the ROI  Default value: []

    :param tetrahedraInROI: Tetrahedra contained in the ROI  Default value: []

    :param drawBoxes: Draw Box(es)  Default value: 0

    :param drawPoints: Draw Points  Default value: 0

    :param drawEdges: Draw Edges  Default value: 0

    :param drawTriangles: Draw Triangles  Default value: 0

    :param drawTetrahedra: Draw Tetrahedra  Default value: 0

    :param drawSize: rendering size for box and topological elements  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, plane=plane, position=position, edges=edges, triangles=triangles, tetrahedra=tetrahedra, computeEdges=computeEdges, computeTriangles=computeTriangles, computeTetrahedra=computeTetrahedra, indices=indices, edgeIndices=edgeIndices, triangleIndices=triangleIndices, tetrahedronIndices=tetrahedronIndices, pointsInROI=pointsInROI, edgesInROI=edgesInROI, trianglesInROI=trianglesInROI, tetrahedraInROI=tetrahedraInROI, drawBoxes=drawBoxes, drawPoints=drawPoints, drawEdges=drawEdges, drawTriangles=drawTriangles, drawTetrahedra=drawTetrahedra, drawSize=drawSize)
    return "PlaneROI", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ValuesFromPositions

.. autofunction:: ValuesFromPositions

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ValuesFromPositions(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, inputValues=None, direction=None, position=None, edges=None, triangles=None, tetrahedra=None, values=None, edgeValues=None, triangleValues=None, tetrahedronValues=None, pointVectors=None, edgeVectors=None, triangleVectors=None, tetrahedronVectors=None, fieldType=None, drawVectors=None, drawVectorLength=None, **kwargs):
    """
    Assign values to primitives (vertex/edge/triangle/tetrahedron) based on a linear interpolation of values along a direction


    :param name: object name  Default value: ValuesFromPositions

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param inputValues: Input values  Default value: []

    :param direction: Direction along which the values are interpolated  Default value: [[0.0, 1.0, 0.0]]

    :param position: Rest position coordinates of the degrees of freedom  Default value: []

    :param edges: Edge Topology  Default value: []

    :param triangles: Triangle Topology  Default value: []

    :param tetrahedra: Tetrahedron Topology  Default value: []

    :param values: Values of the points contained in the ROI  Default value: []

    :param edgeValues: Values of the edges contained in the ROI  Default value: []

    :param triangleValues: Values of the triangles contained in the ROI  Default value: []

    :param tetrahedronValues: Values of the tetrahedra contained in the ROI  Default value: []

    :param pointVectors: Vectors of the points contained in the ROI  Default value: []

    :param edgeVectors: Vectors of the edges contained in the ROI  Default value: []

    :param triangleVectors: Vectors of the triangles contained in the ROI  Default value: []

    :param tetrahedronVectors: Vectors of the tetrahedra contained in the ROI  Default value: []

    :param fieldType: field type of output elements  Default value: Scalar

    :param drawVectors: draw vectors line  Default value: 0

    :param drawVectorLength: vector length visualisation.   Default value: 10.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, inputValues=inputValues, direction=direction, position=position, edges=edges, triangles=triangles, tetrahedra=tetrahedra, values=values, edgeValues=edgeValues, triangleValues=triangleValues, tetrahedronValues=tetrahedronValues, pointVectors=pointVectors, edgeVectors=edgeVectors, triangleVectors=triangleVectors, tetrahedronVectors=tetrahedronVectors, fieldType=fieldType, drawVectors=drawVectors, drawVectorLength=drawVectorLength)
    return "ValuesFromPositions", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PythonScriptDataEngine

.. autofunction:: PythonScriptDataEngine

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PythonScriptDataEngine(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, classname=None, variables=None, timingEnabled=None, autoreload=None, **kwargs):
    """
    A Sofa DataEngine scripted in python


    :param name: object name  Default value: PythonScriptDataEngine

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param filename: Python script filename  Default value: 

    :param classname: Python class implemented in the script to instanciate for the controller  Default value: 

    :param variables: Array of string variables (equivalent to a c-like argv)  Default value: []

    :param timingEnabled: Set this attribute to true or false to activate/deactivate the gathering of timing statistics on the python execution time. Default value is setto true.  Default value: 1

    :param autoreload: Automatically reload the file when the source code is changed. Default value is set to false  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, classname=classname, variables=variables, timingEnabled=timingEnabled, autoreload=autoreload)
    return "PythonScriptDataEngine", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component EvalSurfaceDistance

.. autofunction:: EvalSurfaceDistance

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def EvalSurfaceDistance(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, draw=None, isToPrint=None, filename=None, period=None, distance=None, distMean=None, distMin=None, distMax=None, distDev=None, rdistMean=None, rdistMin=None, rdistMax=None, rdistDev=None, maxDist=None, **kwargs):
    """
    Periodically compute the distance between 2 set of points


    :param name: object name  Default value: EvalSurfaceDistance

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param draw: activate rendering of lines between associated points  Default value: 1

    :param isToPrint: suppress somes data before using save as function  Default value: 0

    :param filename: output file name  Default value: 

    :param period: period between outputs  Default value: 0.0

    :param distance: distances (OUTPUT)  Default value: []

    :param distMean: mean distance (OUTPUT)  Default value: 1.0

    :param distMin: min distance (OUTPUT)  Default value: 1.0

    :param distMax: max distance (OUTPUT)  Default value: 1.0

    :param distDev: distance standard deviation (OUTPUT)  Default value: 1.0

    :param rdistMean: mean relative distance (OUTPUT)  Default value: 1.0

    :param rdistMin: min relative distance (OUTPUT)  Default value: 1.0

    :param rdistMax: max relative distance (OUTPUT)  Default value: 1.0

    :param rdistDev: relative distance standard deviation (OUTPUT)  Default value: 1.0

    :param maxDist: alarm distance for proximity detection  Default value: 1.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, draw=draw, isToPrint=isToPrint, filename=filename, period=period, distance=distance, distMean=distMean, distMin=distMin, distMax=distMax, distDev=distDev, rdistMean=rdistMean, rdistMin=rdistMin, rdistMax=rdistMax, rdistDev=rdistDev, maxDist=maxDist)
    return "EvalSurfaceDistance", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MeshTetraStuffing

.. autofunction:: MeshTetraStuffing

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MeshTetraStuffing(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, vbbox=None, size=None, inputPoints=None, inputTriangles=None, inputQuads=None, outputPoints=None, outputTetrahedra=None, alphaLong=None, alphaShort=None, snapPoints=None, splitTetrahedra=None, draw=None, **kwargs):
    """
    Create a tetrahedral volume mesh from a surface, using the algorithm from F. Labelle and J.R. Shewchuk, "Isosurface Stuffing: Fast Tetrahedral Meshes with Good Dihedral Angles", SIGGRAPH 2007.


    :param name: object name  Default value: MeshTetraStuffing

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param vbbox: BBox to restrict the volume to  Default value: [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0]]

    :param size: Size of the generate tetrahedra. If negative, number of grid cells in the largest bbox dimension  Default value: -8.0

    :param inputPoints: Input surface mesh points  Default value: []

    :param inputTriangles: Input surface mesh triangles  Default value: []

    :param inputQuads: Input surface mesh quads  Default value: []

    :param outputPoints: Output volume mesh points  Default value: []

    :param outputTetrahedra: Output volume mesh tetrahedra  Default value: []

    :param alphaLong: Minimum alpha values on long edges when snapping points  Default value: 0.24999

    :param alphaShort: Minimum alpha values on short edges when snapping points  Default value: 0.42978

    :param snapPoints: Snap points to the surface if intersections on edges are closed to given alpha values  Default value: 0

    :param splitTetrahedra: Split tetrahedra crossing the surface  Default value: 0

    :param draw: Activate rendering of internal datasets  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, vbbox=vbbox, size=size, inputPoints=inputPoints, inputTriangles=inputTriangles, inputQuads=inputQuads, outputPoints=outputPoints, outputTetrahedra=outputTetrahedra, alphaLong=alphaLong, alphaShort=alphaShort, snapPoints=snapPoints, splitTetrahedra=splitTetrahedra, draw=draw)
    return "MeshTetraStuffing", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component DataDisplay

.. autofunction:: DataDisplay

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def DataDisplay(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, position=None, restPosition=None, normal=None, maximalRange=None, pointData=None, triangleData=None, quadData=None, pointTriangleData=None, pointQuadData=None, colorNaN=None, userRange=None, currentMin=None, currentMax=None, shininess=None, **kwargs):
    """
    Rendering of meshes colored by data


    :param name: object name  Default value: DataDisplay

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param position: Vertices coordinates  Default value: []

    :param restPosition: Vertices rest coordinates  Default value: []

    :param normal: Normals of the model  Default value: []

    :param maximalRange: Keep the maximal range through all timesteps  Default value: 1

    :param pointData: Data associated with nodes  Default value: []

    :param triangleData: Data associated with triangles  Default value: []

    :param quadData: Data associated with quads  Default value: []

    :param pointTriangleData: Data associated with nodes per triangle  Default value: []

    :param pointQuadData: Data associated with nodes per quad  Default value: []

    :param colorNaN: Color used for NaN values.(default=[0.0,0.0,0.0,1.0])  Default value: [[0.0, 0.0, 0.0, 1.0]]

    :param userRange: Clamp to this values (if max>min)  Default value: [[1.0, -1.0]]

    :param currentMin: Current min range  Default value: 0.0

    :param currentMax: Current max range  Default value: 0.0

    :param shininess: Shininess for rendering point-based data [0,128].  <0 means no specularity  Default value: -1.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, position=position, restPosition=restPosition, normal=normal, maximalRange=maximalRange, pointData=pointData, triangleData=triangleData, quadData=quadData, pointTriangleData=pointTriangleData, pointQuadData=pointQuadData, colorNaN=colorNaN, userRange=userRange, currentMin=currentMin, currentMax=currentMax, shininess=shininess)
    return "DataDisplay", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component InputEventReader

.. autofunction:: InputEventReader

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def InputEventReader(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, inverseSense=None, printEvent=None, key1=None, key2=None, writeEvents=None, outputFilename=None, **kwargs):
    """
    Read events from file


    :param name: object name  Default value: InputEventReader

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: input events file name  Default value: /dev/input/mouse2

    :param inverseSense: inverse the sense of the mouvement  Default value: 0

    :param printEvent: Print event informations  Default value: 0

    :param key1: Key event generated when the left pedal is pressed  Default value: 48

    :param key2: Key event generated when the right pedal is pressed  Default value: 49

    :param writeEvents: If true, write incoming events ; if false, read events from that file (if an output filename is provided)  Default value: 0

    :param outputFilename: Other filename where events will be stored (or read)  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, inverseSense=inverseSense, printEvent=printEvent, key1=key1, key2=key2, writeEvents=writeEvents, outputFilename=outputFilename)
    return "InputEventReader", params



import Sofa


class SceneElectroMechanical(Sofa.PythonScriptController):
    def __init__(self, node):
        self._total_simu_time = 0
        self.createGraph(node)

    def createGraph(self, root):
        # root
        {}

    def onBeginAnimationStep(self, dt):
        print(f"Simulation time: {self._total_simu_time}")
        self._total_simu_time += dt

def createScene(root_node):
    SceneElectroMechanical(root_node)



# -*- coding: utf-8 -*-


"""
Module LinearSolver

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    MinResLinearSolver

    SparseLDLSolver

    ShewchukPCGLinearSolver

    LULinearSolver

    WarpPreconditioner

    SVDLinearSolver

    PrecomputedLinearSolver

    CGLinearSolver

    CholeskySolver

    BTDLinearSolver

    JacobiPreconditioner

    SparseCholeskySolver

    BlockJacobiPreconditioner

    PrecomputedWarpPreconditioner

    SparseLUSolver

    SSORPreconditioner



Content:
========

.. automodule::

    MinResLinearSolver

    SparseLDLSolver

    ShewchukPCGLinearSolver

    LULinearSolver

    WarpPreconditioner

    SVDLinearSolver

    PrecomputedLinearSolver

    CGLinearSolver

    CholeskySolver

    BTDLinearSolver

    JacobiPreconditioner

    SparseCholeskySolver

    BlockJacobiPreconditioner

    PrecomputedWarpPreconditioner

    SparseLUSolver

    SSORPreconditioner



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['MinResLinearSolver', 'SparseLDLSolver', 'ShewchukPCGLinearSolver', 'LULinearSolver', 'WarpPreconditioner', 'SVDLinearSolver', 'PrecomputedLinearSolver', 'CGLinearSolver', 'CholeskySolver', 'BTDLinearSolver', 'JacobiPreconditioner', 'SparseCholeskySolver', 'BlockJacobiPreconditioner', 'PrecomputedWarpPreconditioner', 'SparseLUSolver', 'SSORPreconditioner']
class LinearSolver:
    from .MinResLinearSolver import MinResLinearSolver
    from .SparseLDLSolver import SparseLDLSolver
    from .ShewchukPCGLinearSolver import ShewchukPCGLinearSolver
    from .LULinearSolver import LULinearSolver
    from .WarpPreconditioner import WarpPreconditioner
    from .SVDLinearSolver import SVDLinearSolver
    from .PrecomputedLinearSolver import PrecomputedLinearSolver
    from .CGLinearSolver import CGLinearSolver
    from .CholeskySolver import CholeskySolver
    from .BTDLinearSolver import BTDLinearSolver
    from .JacobiPreconditioner import JacobiPreconditioner
    from .SparseCholeskySolver import SparseCholeskySolver
    from .BlockJacobiPreconditioner import BlockJacobiPreconditioner
    from .PrecomputedWarpPreconditioner import PrecomputedWarpPreconditioner
    from .SparseLUSolver import SparseLUSolver
    from .SSORPreconditioner import SSORPreconditioner



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ShapeMatching

.. autofunction:: ShapeMatching

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ShapeMatching(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, iterations=None, affineRatio=None, fixedweight=None, fixedPosition0=None, fixedPosition=None, position=None, cluster=None, targetPosition=None, **kwargs):
    """
    Compute target positions using shape matching deformation method by Mueller et al.


    :param name: object name  Default value: ShapeMatching

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param iterations: Number of iterations.  Default value: 1

    :param affineRatio: Blending between affine and rigid.  Default value: 0.0

    :param fixedweight: weight of fixed particles.  Default value: 1.0

    :param fixedPosition0: rest positions of non mechanical particles.  Default value: []

    :param fixedPosition: current (fixed) positions of non mechanical particles.  Default value: []

    :param position: Input positions.  Default value: []

    :param cluster: Input clusters.  Default value: []

    :param targetPosition: Computed target positions.  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, iterations=iterations, affineRatio=affineRatio, fixedweight=fixedweight, fixedPosition0=fixedPosition0, fixedPosition=fixedPosition, position=position, cluster=cluster, targetPosition=targetPosition)
    return "ShapeMatching", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component BoxROI

.. autofunction:: BoxROI

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def BoxROI(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, box=None, orientedBox=None, position=None, edges=None, triangles=None, tetrahedra=None, hexahedra=None, quad=None, computeEdges=None, computeTriangles=None, computeTetrahedra=None, computeHexahedra=None, computeQuad=None, strict=None, indices=None, edgeIndices=None, triangleIndices=None, tetrahedronIndices=None, hexahedronIndices=None, quadIndices=None, pointsInROI=None, edgesInROI=None, trianglesInROI=None, tetrahedraInROI=None, hexahedraInROI=None, quadInROI=None, nbIndices=None, drawBoxes=None, drawPoints=None, drawEdges=None, drawTriangles=None, drawTetrahedra=None, drawHexahedra=None, drawQuads=None, drawSize=None, doUpdate=None, rest_position=None, isVisible=None, **kwargs):
    """
    Find the primitives (vertex/edge/triangle/quad/tetrahedron/hexahedron) inside given boxes
Find the primitives (vertex/edge/triangle/tetrahedron) inside a given box
Find the primitives (vertex/edge/triangle/tetrahedron) inside a given box


    :param name: object name  Default value: BoxROI

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param box: List of boxes defined by xmin,ymin,zmin, xmax,ymax,zmax  Default value: []

    :param orientedBox: List of boxes defined by 3 points (p0, p1, p2) and a depth distance 
A parallelogram will be defined by (p0, p1, p2, p3 = p0 + (p2-p1)). 
The box will finaly correspond to the parallelogram extrusion of depth/2 
along its normal and depth/2 in the opposite direction.   Default value: []

    :param position: Rest position coordinates of the degrees of freedom. 
If empty the positions from a MechanicalObject then a MeshLoader are searched in the current context. 
If none are found the parent's context is searched for MechanicalObject.  Default value: []

    :param edges: Edge Topology  Default value: []

    :param triangles: Triangle Topology  Default value: []

    :param tetrahedra: Tetrahedron Topology  Default value: []

    :param hexahedra: Hexahedron Topology  Default value: []

    :param quad: Quad Topology  Default value: []

    :param computeEdges: If true, will compute edge list and index list inside the ROI. (default = true)  Default value: 1

    :param computeTriangles: If true, will compute triangle list and index list inside the ROI. (default = true)  Default value: 1

    :param computeTetrahedra: If true, will compute tetrahedra list and index list inside the ROI. (default = true)  Default value: 1

    :param computeHexahedra: If true, will compute hexahedra list and index list inside the ROI. (default = true)  Default value: 1

    :param computeQuad: If true, will compute quad list and index list inside the ROI. (default = true)  Default value: 1

    :param strict: If true, an element is inside the box iif all of its nodes are inside. If False, only the center point of the element is checked. (default = true)  Default value: 1

    :param indices: Indices of the points contained in the ROI  Default value: [[0]]

    :param edgeIndices: Indices of the edges contained in the ROI  Default value: []

    :param triangleIndices: Indices of the triangles contained in the ROI  Default value: []

    :param tetrahedronIndices: Indices of the tetrahedra contained in the ROI  Default value: []

    :param hexahedronIndices: Indices of the hexahedra contained in the ROI  Default value: []

    :param quadIndices: Indices of the quad contained in the ROI  Default value: []

    :param pointsInROI: Points contained in the ROI  Default value: []

    :param edgesInROI: Edges contained in the ROI  Default value: []

    :param trianglesInROI: Triangles contained in the ROI  Default value: []

    :param tetrahedraInROI: Tetrahedra contained in the ROI  Default value: []

    :param hexahedraInROI: Hexahedra contained in the ROI  Default value: []

    :param quadInROI: Quad contained in the ROI  Default value: []

    :param nbIndices: Number of selected indices  Default value: 0

    :param drawBoxes: Draw Boxes. (default = false)  Default value: 0

    :param drawPoints: Draw Points. (default = false)  Default value: 0

    :param drawEdges: Draw Edges. (default = false)  Default value: 0

    :param drawTriangles: Draw Triangles. (default = false)  Default value: 0

    :param drawTetrahedra: Draw Tetrahedra. (default = false)  Default value: 0

    :param drawHexahedra: Draw Tetrahedra. (default = false)  Default value: 0

    :param drawQuads: Draw Quads. (default = false)  Default value: 0

    :param drawSize: rendering size for box and topological elements  Default value: 0.0

    :param doUpdate: If true, updates the selection at the beginning of simulation steps. (default = true)  Default value: 1

    :param rest_position: (deprecated) Replaced with the attribute 'position'  Default value: []

    :param isVisible: (deprecated)Replaced with the attribute 'drawBoxes'  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, box=box, orientedBox=orientedBox, position=position, edges=edges, triangles=triangles, tetrahedra=tetrahedra, hexahedra=hexahedra, quad=quad, computeEdges=computeEdges, computeTriangles=computeTriangles, computeTetrahedra=computeTetrahedra, computeHexahedra=computeHexahedra, computeQuad=computeQuad, strict=strict, indices=indices, edgeIndices=edgeIndices, triangleIndices=triangleIndices, tetrahedronIndices=tetrahedronIndices, hexahedronIndices=hexahedronIndices, quadIndices=quadIndices, pointsInROI=pointsInROI, edgesInROI=edgesInROI, trianglesInROI=trianglesInROI, tetrahedraInROI=tetrahedraInROI, hexahedraInROI=hexahedraInROI, quadInROI=quadInROI, nbIndices=nbIndices, drawBoxes=drawBoxes, drawPoints=drawPoints, drawEdges=drawEdges, drawTriangles=drawTriangles, drawTetrahedra=drawTetrahedra, drawHexahedra=drawHexahedra, drawQuads=drawQuads, drawSize=drawSize, doUpdate=doUpdate, rest_position=rest_position, isVisible=isVisible)
    return "BoxROI", params



# -*- coding: utf-8 -*-


"""
Module Loader

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    MeshTetrahedrisationLoader

    StringMeshCreator

    MeshGmshLoader

    MeshXspLoader

    MeshTrianLoader

    MeshINPLoader

    MeshTriangulationLoader

    MeshOffLoader

    GridMeshCreator

    VoxelGridLoader

    SphereLoader

    MeshObjLoader

    GIDMeshLoader

    CardiacVTKLoader

    OffSequenceLoader

    MeshSTLLoader

    MeshVTKLoader

    MeshDxfLoader



Content:
========

.. automodule::

    MeshTetrahedrisationLoader

    StringMeshCreator

    MeshGmshLoader

    MeshXspLoader

    MeshTrianLoader

    MeshINPLoader

    MeshTriangulationLoader

    MeshOffLoader

    GridMeshCreator

    VoxelGridLoader

    SphereLoader

    MeshObjLoader

    GIDMeshLoader

    CardiacVTKLoader

    OffSequenceLoader

    MeshSTLLoader

    MeshVTKLoader

    MeshDxfLoader



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['MeshTetrahedrisationLoader', 'StringMeshCreator', 'MeshGmshLoader', 'MeshXspLoader', 'MeshTrianLoader', 'MeshINPLoader', 'MeshTriangulationLoader', 'MeshOffLoader', 'GridMeshCreator', 'VoxelGridLoader', 'SphereLoader', 'MeshObjLoader', 'GIDMeshLoader', 'CardiacVTKLoader', 'OffSequenceLoader', 'MeshSTLLoader', 'MeshVTKLoader', 'MeshDxfLoader']
class Loader:
    from .MeshTetrahedrisationLoader import MeshTetrahedrisationLoader
    from .StringMeshCreator import StringMeshCreator
    from .MeshGmshLoader import MeshGmshLoader
    from .MeshXspLoader import MeshXspLoader
    from .MeshTrianLoader import MeshTrianLoader
    from .MeshINPLoader import MeshINPLoader
    from .MeshTriangulationLoader import MeshTriangulationLoader
    from .MeshOffLoader import MeshOffLoader
    from .GridMeshCreator import GridMeshCreator
    from .VoxelGridLoader import VoxelGridLoader
    from .SphereLoader import SphereLoader
    from .MeshObjLoader import MeshObjLoader
    from .GIDMeshLoader import GIDMeshLoader
    from .CardiacVTKLoader import CardiacVTKLoader
    from .OffSequenceLoader import OffSequenceLoader
    from .MeshSTLLoader import MeshSTLLoader
    from .MeshVTKLoader import MeshVTKLoader
    from .MeshDxfLoader import MeshDxfLoader



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component EdgePressureForceField

.. autofunction:: EdgePressureForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def EdgePressureForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, edgePressureMap=None, pressure=None, edgeIndices=None, edges=None, normal=None, dmin=None, dmax=None, arrowSizeCoef=None, p_intensity=None, binormal=None, showForces=None, **kwargs):
    """
    EdgePressure


    :param name: object name  Default value: EdgePressureForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param edgePressureMap: map between edge indices and their pressure  Default value: 

    :param pressure: Pressure force per unit area  Default value: [[0.0, 0.0, 0.0]]

    :param edgeIndices: Indices of edges separated with commas where a pressure is applied  Default value: []

    :param edges: List of edges where a pressure is applied  Default value: []

    :param normal: Normal direction for the plane selection of edges  Default value: [[0.0, 0.0, 0.0]]

    :param dmin: Minimum distance from the origin along the normal direction  Default value: 0.0

    :param dmax: Maximum distance from the origin along the normal direction  Default value: 0.0

    :param arrowSizeCoef: Size of the drawn arrows (0->no arrows, sign->direction of drawing  Default value: 0.0

    :param p_intensity: pressure intensity on edge normal  Default value: []

    :param binormal: Binormal of the 2D plane  Default value: [[0.0, 0.0, 0.0]]

    :param showForces: draw arrows of edge pressures  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, edgePressureMap=edgePressureMap, pressure=pressure, edgeIndices=edgeIndices, edges=edges, normal=normal, dmin=dmin, dmax=dmax, arrowSizeCoef=arrowSizeCoef, p_intensity=p_intensity, binormal=binormal, showForces=showForces)
    return "EdgePressureForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ProximityROI

.. autofunction:: ProximityROI

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ProximityROI(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, centers=None, radii=None, N=None, position=None, indices=None, pointsInROI=None, distance=None, indicesOut=None, drawSphere=None, drawPoints=None, drawSize=None, **kwargs):
    """
    Find the N closest primitives from a given position


    :param name: object name  Default value: ProximityROI

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param centers: Center(s) of the sphere(s)  Default value: []

    :param radii: Radius(i) of the sphere(s)  Default value: []

    :param N: Maximum number of points to select  Default value: 0

    :param position: Rest position coordinates of the degrees of freedom  Default value: []

    :param indices: Indices of the points contained in the ROI  Default value: [[0]]

    :param pointsInROI: Points contained in the ROI  Default value: []

    :param distance: distance between the points contained in the ROI and the closest center.  Default value: []

    :param indicesOut: Indices of the points not contained in the ROI  Default value: []

    :param drawSphere: Draw shpere(s)  Default value: 0

    :param drawPoints: Draw Points  Default value: 0

    :param drawSize: rendering size for box and topological elements  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, centers=centers, radii=radii, N=N, position=position, indices=indices, pointsInROI=pointsInROI, distance=distance, indicesOut=indicesOut, drawSphere=drawSphere, drawPoints=drawPoints, drawSize=drawSize)
    return "ProximityROI", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OglShader

.. autofunction:: OglShader

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OglShader(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, turnOn=None, passive=None, fileVertexShaders=None, fileFragmentShaders=None, fileGeometryShaders=None, fileTessellationControlShaders=None, fileTessellationEvaluationShaders=None, geometryInputType=None, geometryOutputType=None, geometryVerticesOut=None, tessellationOuterLevel=None, tessellationInnerLevel=None, indexActiveShader=None, backfaceWriting=None, clampVertexColor=None, **kwargs):
    """
    OglShader


    :param name: object name  Default value: OglShader

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param turnOn: Turn On the shader?  Default value: 1

    :param passive: Will this shader be activated manually or automatically?  Default value: 0

    :param fileVertexShaders: Set the vertex shader filename to load  Default value: [ 'shaders/toonShading.vert' ]

    :param fileFragmentShaders: Set the fragment shader filename to load  Default value: [ 'shaders/toonShading.frag' ]

    :param fileGeometryShaders: Set the geometry shader filename to load  Default value: []

    :param fileTessellationControlShaders: Set the tessellation control filename to load  Default value: []

    :param fileTessellationEvaluationShaders: Set the tessellation evaluation filename to load  Default value: []

    :param geometryInputType: Set input types for the geometry shader  Default value: -1

    :param geometryOutputType: Set output types for the geometry shader  Default value: -1

    :param geometryVerticesOut: Set max number of vertices in output for the geometry shader  Default value: -1

    :param tessellationOuterLevel: For tessellation without control shader: default outer level (edge subdivisions)  Default value: 1.0

    :param tessellationInnerLevel: For tessellation without control shader: default inner level (face subdivisions)  Default value: 1.0

    :param indexActiveShader: Set current active shader  Default value: 0

    :param backfaceWriting: it enables writing to gl_BackColor inside a GLSL vertex shader  Default value: 0

    :param clampVertexColor: clamp the vertex color between 0 and 1  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, turnOn=turnOn, passive=passive, fileVertexShaders=fileVertexShaders, fileFragmentShaders=fileFragmentShaders, fileGeometryShaders=fileGeometryShaders, fileTessellationControlShaders=fileTessellationControlShaders, fileTessellationEvaluationShaders=fileTessellationEvaluationShaders, geometryInputType=geometryInputType, geometryOutputType=geometryOutputType, geometryVerticesOut=geometryVerticesOut, tessellationOuterLevel=tessellationOuterLevel, tessellationInnerLevel=tessellationInnerLevel, indexActiveShader=indexActiveShader, backfaceWriting=backfaceWriting, clampVertexColor=clampVertexColor)
    return "OglShader", params



# -*- coding: utf-8 -*-


"""
Module ConfigurationSetting

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    SofaDefaultPathSetting

    StartNavigationButtonSetting

    FixPickedParticleButtonSetting

    AttachBodyButtonSetting

    AddFrameButtonSetting

    ViewerSetting

    StatsSetting

    BackgroundSetting

    AddRecordedCameraButtonSetting



Content:
========

.. automodule::

    SofaDefaultPathSetting

    StartNavigationButtonSetting

    FixPickedParticleButtonSetting

    AttachBodyButtonSetting

    AddFrameButtonSetting

    ViewerSetting

    StatsSetting

    BackgroundSetting

    AddRecordedCameraButtonSetting



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['SofaDefaultPathSetting', 'StartNavigationButtonSetting', 'FixPickedParticleButtonSetting', 'AttachBodyButtonSetting', 'AddFrameButtonSetting', 'ViewerSetting', 'StatsSetting', 'BackgroundSetting', 'AddRecordedCameraButtonSetting']
class ConfigurationSetting:
    from .SofaDefaultPathSetting import SofaDefaultPathSetting
    from .StartNavigationButtonSetting import StartNavigationButtonSetting
    from .FixPickedParticleButtonSetting import FixPickedParticleButtonSetting
    from .AttachBodyButtonSetting import AttachBodyButtonSetting
    from .AddFrameButtonSetting import AddFrameButtonSetting
    from .ViewerSetting import ViewerSetting
    from .StatsSetting import StatsSetting
    from .BackgroundSetting import BackgroundSetting
    from .AddRecordedCameraButtonSetting import AddRecordedCameraButtonSetting



# -*- coding: utf-8 -*-


"""
Module AnimationLoop

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    FreeMotionAnimationLoop

    DefaultAnimationLoop

    ConstraintAnimationLoop

    MultiStepAnimationLoop

    MultiTagAnimationLoop



Content:
========

.. automodule::

    FreeMotionAnimationLoop

    DefaultAnimationLoop

    ConstraintAnimationLoop

    MultiStepAnimationLoop

    MultiTagAnimationLoop



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['FreeMotionAnimationLoop', 'DefaultAnimationLoop', 'ConstraintAnimationLoop', 'MultiStepAnimationLoop', 'MultiTagAnimationLoop']
class AnimationLoop:
    from .FreeMotionAnimationLoop import FreeMotionAnimationLoop
    from .DefaultAnimationLoop import DefaultAnimationLoop
    from .ConstraintAnimationLoop import ConstraintAnimationLoop
    from .MultiStepAnimationLoop import MultiStepAnimationLoop
    from .MultiTagAnimationLoop import MultiTagAnimationLoop



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component IndicesFromValues

.. autofunction:: IndicesFromValues

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def IndicesFromValues(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, values=None, indices=None, otherIndices=None, recursiveSearch=None, **kwargs):
    """
    Find the indices of a list of values within a larger set of values


    :param name: object name  Default value: IndicesFromValues

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param values: input values  Default value: []

    :param global: Global values, in which the input values are searched (NB: use the kwargs syntax as name is a reserved word in python)

    :param indices: Output indices of the given values, searched in global  Default value: []

    :param otherIndices: Output indices of the other values, (NOT the given ones) searched in global  Default value: []

    :param recursiveSearch: if set to true, output are indices of the "global" data matching with one of the values  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, values=values, indices=indices, otherIndices=otherIndices, recursiveSearch=recursiveSearch)
    return "IndicesFromValues", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GenerateSphere

.. autofunction:: GenerateSphere

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GenerateSphere(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, output_TetrahedraPosition=None, tetrahedra=None, output_TrianglesPosition=None, triangles=None, BezierTetrahedronDegree=None, BezierTetrahedronWeights=None, isBezierTetrahedronRational=None, BezierTriangleDegree=None, BezierTriangleWeights=None, isBezierTriangleRational=None, radius=None, origin=None, tessellationDegree=None, platonicSolid=None, **kwargs):
    """
    Generate a sphereical (Bezier) Tetrahedral and Triangular Mesh


    :param name: object name  Default value: GenerateSphere

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param output_TetrahedraPosition: output array of 3d points of tetrahedra mesh  Default value: []

    :param tetrahedra: output mesh tetrahedra  Default value: []

    :param output_TrianglesPosition: output array of 3d points of triangle mesh  Default value: []

    :param triangles: output triangular mesh  Default value: []

    :param BezierTetrahedronDegree: order of Bezier tetrahedra  Default value: 0

    :param BezierTetrahedronWeights: weights of rational Bezier tetrahedra  Default value: []

    :param isBezierTetrahedronRational: booleans indicating if each Bezier tetrahedron is rational or integral  Default value: []

    :param BezierTriangleDegree: order of Bezier triangles  Default value: 0

    :param BezierTriangleWeights: weights of rational Bezier triangles  Default value: []

    :param isBezierTriangleRational: booleans indicating if each Bezier triangle is rational or integral  Default value: []

    :param radius: input sphere radius  Default value: 0.2

    :param origin: sphere center point  Default value: [[0.0, 0.0, 0.0]]

    :param tessellationDegree: Degree of tessellation of each Platonic triangulation  Default value: 1

    :param platonicSolid: name of the Platonic triangulation used to create the spherical dome : either "tetrahedron", "octahedron" or "icosahedron"  Default value: icosahedron


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, output_TetrahedraPosition=output_TetrahedraPosition, tetrahedra=tetrahedra, output_TrianglesPosition=output_TrianglesPosition, triangles=triangles, BezierTetrahedronDegree=BezierTetrahedronDegree, BezierTetrahedronWeights=BezierTetrahedronWeights, isBezierTetrahedronRational=isBezierTetrahedronRational, BezierTriangleDegree=BezierTriangleDegree, BezierTriangleWeights=BezierTriangleWeights, isBezierTriangleRational=isBezierTriangleRational, radius=radius, origin=origin, tessellationDegree=tessellationDegree, platonicSolid=platonicSolid)
    return "GenerateSphere", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SubsetTopology

.. autofunction:: SubsetTopology

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SubsetTopology(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, box=None, centers=None, radii=None, direction=None, normal=None, edgeAngle=None, triAngle=None, rest_position=None, edges=None, triangles=None, quads=None, tetrahedra=None, hexahedra=None, tetrahedraInput=None, indices=None, edgeIndices=None, triangleIndices=None, quadIndices=None, tetrahedronIndices=None, hexahedronIndices=None, pointsInROI=None, pointsOutROI=None, edgesInROI=None, edgesOutROI=None, trianglesInROI=None, trianglesOutROI=None, quadsInROI=None, quadsOutROI=None, tetrahedraInROI=None, tetrahedraOutROI=None, hexahedraInROI=None, hexahedraOutROI=None, nbrborder=None, localIndices=None, drawROI=None, drawPoints=None, drawEdges=None, drawTriangle=None, drawTetrahedra=None, drawSize=None, **kwargs):
    """
    Engine used to create subset topology given box, sphere, plan, ...


    :param name: object name  Default value: SubsetTopology

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param box: Box defined by xmin,ymin,zmin, xmax,ymax,zmax  Default value: [[0.0, 0.0, 0.0, 1.0, 1.0, 1.0]]

    :param centers: Center(s) of the sphere(s)  Default value: []

    :param radii: Radius(i) of the sphere(s)  Default value: []

    :param direction: Edge direction(if edgeAngle > 0)  Default value: [[0.0, 0.0, 0.0]]

    :param normal: Normal direction of the triangles (if triAngle > 0)  Default value: [[0.0, 0.0, 0.0]]

    :param edgeAngle: Max angle between the direction of the selected edges and the specified direction  Default value: 0.0

    :param triAngle: Max angle between the normal of the selected triangle and the specified normal direction  Default value: 0.0

    :param rest_position: Rest position coordinates of the degrees of freedom  Default value: []

    :param edges: Edge Topology  Default value: []

    :param triangles: Triangle Topology  Default value: []

    :param quads: Quad Topology  Default value: []

    :param tetrahedra: Tetrahedron Topology  Default value: []

    :param hexahedra: Hexahedron Topology  Default value: []

    :param tetrahedraInput: Indices of the tetrahedra to keep  Default value: []

    :param indices: Indices of the points contained in the ROI  Default value: [[0]]

    :param edgeIndices: Indices of the edges contained in the ROI  Default value: []

    :param triangleIndices: Indices of the triangles contained in the ROI  Default value: []

    :param quadIndices: Indices of the quads contained in the ROI  Default value: []

    :param tetrahedronIndices: Indices of the tetrahedra contained in the ROI  Default value: []

    :param hexahedronIndices: Indices of the hexahedra contained in the ROI  Default value: []

    :param pointsInROI: Points contained in the ROI  Default value: []

    :param pointsOutROI: Points out of the ROI  Default value: []

    :param edgesInROI: Edges contained in the ROI  Default value: []

    :param edgesOutROI: Edges out of the ROI  Default value: []

    :param trianglesInROI: Triangles contained in the ROI  Default value: []

    :param trianglesOutROI: Triangles out of the ROI  Default value: []

    :param quadsInROI: Quads contained in the ROI  Default value: []

    :param quadsOutROI: Quads out of the ROI  Default value: []

    :param tetrahedraInROI: Tetrahedra contained in the ROI  Default value: []

    :param tetrahedraOutROI: Tetrahedra out of the ROI  Default value: []

    :param hexahedraInROI: Hexahedra contained in the ROI  Default value: []

    :param hexahedraOutROI: Hexahedra out of the ROI  Default value: []

    :param nbrborder: If localIndices option is activated, will give the number of vertices on the border of the ROI (being the n first points of each output Topology).   Default value: 0

    :param localIndices: If true, will compute local dof indices in topological elements  Default value: 0

    :param drawROI: Draw ROI  Default value: 0

    :param drawPoints: Draw Points  Default value: 0

    :param drawEdges: Draw Edges  Default value: 0

    :param drawTriangle: Draw Triangles  Default value: 0

    :param drawTetrahedra: Draw Tetrahedra  Default value: 0

    :param drawSize: rendering size for box and topological elements  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, box=box, centers=centers, radii=radii, direction=direction, normal=normal, edgeAngle=edgeAngle, triAngle=triAngle, rest_position=rest_position, edges=edges, triangles=triangles, quads=quads, tetrahedra=tetrahedra, hexahedra=hexahedra, tetrahedraInput=tetrahedraInput, indices=indices, edgeIndices=edgeIndices, triangleIndices=triangleIndices, quadIndices=quadIndices, tetrahedronIndices=tetrahedronIndices, hexahedronIndices=hexahedronIndices, pointsInROI=pointsInROI, pointsOutROI=pointsOutROI, edgesInROI=edgesInROI, edgesOutROI=edgesOutROI, trianglesInROI=trianglesInROI, trianglesOutROI=trianglesOutROI, quadsInROI=quadsInROI, quadsOutROI=quadsOutROI, tetrahedraInROI=tetrahedraInROI, tetrahedraOutROI=tetrahedraOutROI, hexahedraInROI=hexahedraInROI, hexahedraOutROI=hexahedraOutROI, nbrborder=nbrborder, localIndices=localIndices, drawROI=drawROI, drawPoints=drawPoints, drawEdges=drawEdges, drawTriangle=drawTriangle, drawTetrahedra=drawTetrahedra, drawSize=drawSize)
    return "SubsetTopology", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component TopologicalChangeProcessor

.. autofunction:: TopologicalChangeProcessor

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def TopologicalChangeProcessor(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, listChanges=None, interval=None, shift=None, loop=None, useDataInputs=None, timeToRemove=None, edgesToRemove=None, trianglesToRemove=None, quadsToRemove=None, tetrahedraToRemove=None, hexahedraToRemove=None, saveIndicesAtInit=None, epsilonSnapPath=None, epsilonSnapBorder=None, draw=None, **kwargs):
    """
    Read topological Changes and process them.


    :param name: object name  Default value: TopologicalChangeProcessor

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param filename: input file name for topological changes.  Default value: 

    :param listChanges: 0 for adding, 1 for removing, 2 for cutting and associated indices.  Default value: []

    :param interval: time duration between 2 actions  Default value: 0.0

    :param shift: shift between times in the file and times when they will be read  Default value: 0.0

    :param loop: set to 'true' to re-read the file when reaching the end  Default value: 0

    :param useDataInputs: If true, will perform operation using Data input lists rather than text file.  Default value: 0

    :param timeToRemove: If using option useDataInputs, time at which will be done the operations. Possibility to use the interval Data also.  Default value: 0.0

    :param edgesToRemove: List of edge IDs to be removed.  Default value: []

    :param trianglesToRemove: List of triangle IDs to be removed.  Default value: []

    :param quadsToRemove: List of quad IDs to be removed.  Default value: []

    :param tetrahedraToRemove: List of tetrahedron IDs to be removed.  Default value: []

    :param hexahedraToRemove: List of hexahedron IDs to be removed.  Default value: []

    :param saveIndicesAtInit: set to 'true' to save the incision to do in the init to incise even after a movement  Default value: 0

    :param epsilonSnapPath: epsilon snap path  Default value: 0.1

    :param epsilonSnapBorder: epsilon snap path  Default value: 0.25

    :param draw: draw information  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, listChanges=listChanges, interval=interval, shift=shift, loop=loop, useDataInputs=useDataInputs, timeToRemove=timeToRemove, edgesToRemove=edgesToRemove, trianglesToRemove=trianglesToRemove, quadsToRemove=quadsToRemove, tetrahedraToRemove=tetrahedraToRemove, hexahedraToRemove=hexahedraToRemove, saveIndicesAtInit=saveIndicesAtInit, epsilonSnapPath=epsilonSnapPath, epsilonSnapBorder=epsilonSnapBorder, draw=draw)
    return "TopologicalChangeProcessor", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GenerateGrid

.. autofunction:: GenerateGrid

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GenerateGrid(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, output_position=None, tetrahedra=None, quads=None, triangles=None, hexahedra=None, min=None, max=None, resolution=None, **kwargs):
    """
    Generate a Grid Tetrahedral or Hexahedral Mesh


    :param name: object name  Default value: GenerateGrid

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param output_position: output array of 3d points  Default value: []

    :param tetrahedra: output mesh tetrahedra  Default value: []

    :param quads: output mesh quads  Default value: []

    :param triangles: output mesh triangles  Default value: []

    :param hexahedra: output mesh hexahedra  Default value: []

    :param min: the 3 coordinates of the minimum corner  Default value: [[0.0, 0.0, 0.0]]

    :param max: the 3 coordinates of the maximum corner  Default value: [[0.0, 0.0, 0.0]]

    :param resolution: the number of cubes in the x,y,z directions. If resolution in the z direction is  0 then a 2D grid is generated  Default value: [[3, 3, 3]]


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, output_position=output_position, tetrahedra=tetrahedra, quads=quads, triangles=triangles, hexahedra=hexahedra, min=min, max=max, resolution=resolution)
    return "GenerateGrid", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SphereROI

.. autofunction:: SphereROI

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SphereROI(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, centers=None, radii=None, direction=None, normal=None, edgeAngle=None, triAngle=None, position=None, edges=None, triangles=None, quads=None, tetrahedra=None, computeEdges=None, computeTriangles=None, computeQuads=None, computeTetrahedra=None, indices=None, edgeIndices=None, triangleIndices=None, quadIndices=None, tetrahedronIndices=None, pointsInROI=None, edgesInROI=None, trianglesInROI=None, quadsInROI=None, tetrahedraInROI=None, indicesOut=None, drawSphere=None, drawPoints=None, drawEdges=None, drawTriangles=None, drawQuads=None, drawTetrahedra=None, drawSize=None, **kwargs):
    """
    Find the primitives (vertex/edge/triangle/tetrahedron) inside a given sphere


    :param name: object name  Default value: SphereROI

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param centers: Center(s) of the sphere(s)  Default value: []

    :param radii: Radius(i) of the sphere(s)  Default value: []

    :param direction: Edge direction(if edgeAngle > 0)  Default value: [[0.0, 0.0, 0.0]]

    :param normal: Normal direction of the triangles (if triAngle > 0)  Default value: [[0.0, 0.0, 0.0]]

    :param edgeAngle: Max angle between the direction of the selected edges and the specified direction  Default value: 0.0

    :param triAngle: Max angle between the normal of the selected triangle and the specified normal direction  Default value: 0.0

    :param position: Rest position coordinates of the degrees of freedom  Default value: []

    :param edges: Edge Topology  Default value: []

    :param triangles: Triangle Topology  Default value: []

    :param quads: Quads Topology  Default value: []

    :param tetrahedra: Tetrahedron Topology  Default value: []

    :param computeEdges: If true, will compute edge list and index list inside the ROI.  Default value: 1

    :param computeTriangles: If true, will compute triangle list and index list inside the ROI.  Default value: 1

    :param computeQuads: If true, will compute quad list and index list inside the ROI.  Default value: 1

    :param computeTetrahedra: If true, will compute tetrahedra list and index list inside the ROI.  Default value: 1

    :param indices: Indices of the points contained in the ROI  Default value: [[0]]

    :param edgeIndices: Indices of the edges contained in the ROI  Default value: []

    :param triangleIndices: Indices of the triangles contained in the ROI  Default value: []

    :param quadIndices: Indices of the quads contained in the ROI  Default value: []

    :param tetrahedronIndices: Indices of the tetrahedra contained in the ROI  Default value: []

    :param pointsInROI: Points contained in the ROI  Default value: []

    :param edgesInROI: Edges contained in the ROI  Default value: []

    :param trianglesInROI: Triangles contained in the ROI  Default value: []

    :param quadsInROI: Quads contained in the ROI  Default value: []

    :param tetrahedraInROI: Tetrahedra contained in the ROI  Default value: []

    :param indicesOut: Indices of the points not contained in the ROI  Default value: []

    :param drawSphere: Draw shpere(s)  Default value: 0

    :param drawPoints: Draw Points  Default value: 0

    :param drawEdges: Draw Edges  Default value: 0

    :param drawTriangles: Draw Triangles  Default value: 0

    :param drawQuads: Draw Quads  Default value: 0

    :param drawTetrahedra: Draw Tetrahedra  Default value: 0

    :param drawSize: rendering size for box and topological elements  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, centers=centers, radii=radii, direction=direction, normal=normal, edgeAngle=edgeAngle, triAngle=triAngle, position=position, edges=edges, triangles=triangles, quads=quads, tetrahedra=tetrahedra, computeEdges=computeEdges, computeTriangles=computeTriangles, computeQuads=computeQuads, computeTetrahedra=computeTetrahedra, indices=indices, edgeIndices=edgeIndices, triangleIndices=triangleIndices, quadIndices=quadIndices, tetrahedronIndices=tetrahedronIndices, pointsInROI=pointsInROI, edgesInROI=edgesInROI, trianglesInROI=trianglesInROI, quadsInROI=quadsInROI, tetrahedraInROI=tetrahedraInROI, indicesOut=indicesOut, drawSphere=drawSphere, drawPoints=drawPoints, drawEdges=drawEdges, drawTriangles=drawTriangles, drawQuads=drawQuads, drawTetrahedra=drawTetrahedra, drawSize=drawSize)
    return "SphereROI", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SpotLight

.. autofunction:: SpotLight

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SpotLight(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, color=None, shadowTextureSize=None, drawSource=None, zNear=None, zFar=None, shadowsEnabled=None, softShadows=None, shadowFactor=None, VSMLightBleeding=None, VSMMinVariance=None, textureUnit=None, modelViewMatrix=None, projectionMatrix=None, fixed=None, position=None, attenuation=None, direction=None, cutoff=None, exponent=None, lookat=None, **kwargs):
    """
    A spot light illuminating the scene.The light has a location and a illumination cone restricting the directionstaken by the rays of light  (can cast shadows).


    :param name: object name  Default value: SpotLight

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param color: Set the color of the light. (default=[1.0,1.0,1.0,1.0])  Default value: [[1.0, 1.0, 1.0, 1.0]]

    :param shadowTextureSize: [Shadowing] Set size for shadow texture   Default value: 0

    :param drawSource: Draw Light Source  Default value: 0

    :param zNear: [Shadowing] Light's ZNear  Default value: 0.0

    :param zFar: [Shadowing] Light's ZFar  Default value: 0.0

    :param shadowsEnabled: [Shadowing] Enable Shadow from this light  Default value: 1

    :param softShadows: [Shadowing] Turn on Soft Shadow from this light  Default value: 0

    :param shadowFactor: [Shadowing] Shadow Factor (decrease/increase darkness)  Default value: 1.0

    :param VSMLightBleeding: [Shadowing] (VSM only) Light bleeding paramter  Default value: 0.0500000007451

    :param VSMMinVariance: [Shadowing] (VSM only) Minimum variance parameter  Default value: 0.0010000000475

    :param textureUnit: [Shadowing] Texture unit for the genereated shadow texture  Default value: 1

    :param modelViewMatrix: [Shadowing] ModelView Matrix  Default value: [[0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0]]

    :param projectionMatrix: [Shadowing] Projection Matrix  Default value: [[0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0], [0.0]]

    :param fixed: Fix light position from the camera  Default value: 0

    :param position: Set the position of the light  Default value: [[-0.7, 0.3, 0.0]]

    :param attenuation: Set the attenuation of the light  Default value: 0.0

    :param direction: Set the direction of the light  Default value: [[0.0, 0.0, -1.0]]

    :param cutoff: Set the angle (cutoff) of the spot  Default value: 30.0

    :param exponent: Set the exponent of the spot  Default value: 1.0

    :param lookat: If true, direction specify the point at which the spotlight should be pointed to  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, color=color, shadowTextureSize=shadowTextureSize, drawSource=drawSource, zNear=zNear, zFar=zFar, shadowsEnabled=shadowsEnabled, softShadows=softShadows, shadowFactor=shadowFactor, VSMLightBleeding=VSMLightBleeding, VSMMinVariance=VSMMinVariance, textureUnit=textureUnit, modelViewMatrix=modelViewMatrix, projectionMatrix=projectionMatrix, fixed=fixed, position=position, attenuation=attenuation, direction=direction, cutoff=cutoff, exponent=exponent, lookat=lookat)
    return "SpotLight", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component VariationalSymplecticSolver

.. autofunction:: VariationalSymplecticSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def VariationalSymplecticSolver(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, newtonError=None, steps=None, rayleighStiffness=None, rayleighMass=None, verbose=None, saveEnergyInFile=None, explicitIntegration=None, file=None, computeHamiltonian=None, hamiltonianEnergy=None, useIncrementalPotentialEnergy=None, threadSafeVisitor=None, **kwargs):
    """
    Implicit time integrator which conserves linear momentum and mechanical energy


    :param name: object name  Default value: VariationalSymplecticSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param newtonError: Error tolerance for Newton iterations  Default value: 0.01

    :param steps: Maximum number of Newton steps  Default value: 5

    :param rayleighStiffness: Rayleigh damping coefficient related to stiffness, > 0  Default value: 0.0

    :param rayleighMass: Rayleigh damping coefficient related to mass, > 0  Default value: 0.0

    :param verbose: Dump information on the residual errors and number of Newton iterations  Default value: 0

    :param saveEnergyInFile: If kinetic and potential energies should be dumped in a CSV file at each iteration  Default value: 0

    :param explicitIntegration: Use explicit integration scheme  Default value: 0

    :param file: File name where kinetic and potential energies are saved in a CSV file  Default value: 

    :param computeHamiltonian: Compute hamiltonian  Default value: 1

    :param hamiltonianEnergy: hamiltonian energy  Default value: 0.0

    :param useIncrementalPotentialEnergy: use real potential energy, if false use approximate potential energy  Default value: 1

    :param threadSafeVisitor: If true, do not use realloc and free visitors in fwdInteractionForceField.  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, newtonError=newtonError, steps=steps, rayleighStiffness=rayleighStiffness, rayleighMass=rayleighMass, verbose=verbose, saveEnergyInFile=saveEnergyInFile, explicitIntegration=explicitIntegration, file=file, computeHamiltonian=computeHamiltonian, hamiltonianEnergy=hamiltonianEnergy, useIncrementalPotentialEnergy=useIncrementalPotentialEnergy, threadSafeVisitor=threadSafeVisitor)
    return "VariationalSymplecticSolver", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component Vertex2Frame

.. autofunction:: Vertex2Frame

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def Vertex2Frame(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, position=None, texCoords=None, normals=None, frames=None, useNormals=None, invertNormals=None, rotation=None, rotationAngle=None, **kwargs):
    """
    

    :param name: object name  Default value: Vertex2Frame

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param position: Vertices of the mesh loaded  Default value: []

    :param texCoords: TexCoords of the mesh loaded  Default value: []

    :param normals: Normals of the mesh loaded  Default value: []

    :param frames: Frames at output  Default value: []

    :param useNormals: Use normals to compute the orientations; if disabled the direction of the x axisof a vertice is the one from this vertice to the next one  Default value: 1

    :param invertNormals: Swap normals  Default value: 0

    :param rotation: Apply a local rotation on the frames. If 0 a x-axis rotation is applied. If 1 a y-axis rotation is applied, If 2 a z-axis rotation is applied.  Default value: 0

    :param rotationAngle: Angle rotation  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, position=position, texCoords=texCoords, normals=normals, frames=frames, useNormals=useNormals, invertNormals=invertNormals, rotation=rotation, rotationAngle=rotationAngle)
    return "Vertex2Frame", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component CardiacSimulationExporter

.. autofunction:: CardiacSimulationExporter

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def CardiacSimulationExporter(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, depolarizationTime=None, localMeasurementPoints=None, Filename=None, ExportSeparateFiles=None, ExportStartStep=None, ExportFileType=None, ExportEveryNSteps=None, ExportDepolarizationTime=None, ExportDepolarizationTimeOnce=None, ExportAPD=None, ExportElapsedTime=None, ExportEc=None, ExportE1d=None, ExportSigmaC=None, ExportScale=None, Potential=None, Points=None, Edges=None, Triangles=None, Quads=None, Tetras=None, Hexas=None, RightVolume=None, LeftVolume=None, RightPressurePv=None, LeftPressurePv=None, RightPressurePat=None, LeftPressurePat=None, RightPressurePar=None, LeftPressurePar=None, RightFlowQ=None, LeftFlowQ=None, APD90=None, stopDepolarizationTime=None, **kwargs):
    """
    Export cardiac information to file at the given time steps.


    :param name: object name  Default value: CardiacSimulationExporter

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 1

    :param depolarizationTime: Time of depolarization for each point  Default value: []

    :param localMeasurementPoints: Optional vector containing the ids 
 of the local points that are 
 studied for depolarization  Default value: []

    :param Filename: Filename  Default value: 

    :param ExportSeparateFiles: True if each type of data is to be exported in its own file  Default value: 0

    :param ExportStartStep: The step at which exporting begins.  Default value: 0

    :param ExportFileType: Export File Type  Default value: 

    :param ExportEveryNSteps: Export a file every N steps  Default value: 0

    :param ExportDepolarizationTime: True if the depolarization times are to be exported.  Default value: 0

    :param ExportDepolarizationTimeOnce: True if the depolarization time is to be exported separately once at the end of calculation.  Default value: 0

    :param ExportAPD: True if the APD is to be exported.  Default value: 0

    :param ExportElapsedTime: True if the overall time elapsed and the time for N steps to elapse is exported.  Default value: 0

    :param ExportEc: ExportEc.  Default value: 0

    :param ExportE1d: ExportE1d.  Default value: 0

    :param ExportSigmaC: ExportSigmaC.  Default value: 0

    :param ExportScale: Scale the MechanicalState by the given value.  Default value: 1.0

    :param Potential: Electric Potential  Default value: []

    :param Points: Point data  Default value: 1

    :param Edges: Edge Data  Default value: 0

    :param Triangles: Triangle Data  Default value: 0

    :param Quads: Quad Data  Default value: 0

    :param Tetras: Tetra Data  Default value: 0

    :param Hexas: Hexa Data  Default value: 0

    :param RightVolume: Right Volume  Default value: 0.0

    :param LeftVolume: Left Volume  Default value: 0.0

    :param RightPressurePv: Right Pressure Pv  Default value: 0.0

    :param LeftPressurePv: Left Pressure Pv  Default value: 0.0

    :param RightPressurePat: Right Pressure Pat  Default value: 0.0

    :param LeftPressurePat: Left Pressure Pat  Default value: 0.0

    :param RightPressurePar: Left Pressure Par  Default value: 0.0

    :param LeftPressurePar: Left Pressure Par  Default value: 0.0

    :param RightFlowQ: Right Flow Q  Default value: 0.0

    :param LeftFlowQ: Left Flow Q  Default value: 0.0

    :param APD90: Action Potential Duration 90%  Default value: []

    :param stopDepolarizationTime: Time at which the depolarization times should all be computed.  Default value: -1.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, depolarizationTime=depolarizationTime, localMeasurementPoints=localMeasurementPoints, Filename=Filename, ExportSeparateFiles=ExportSeparateFiles, ExportStartStep=ExportStartStep, ExportFileType=ExportFileType, ExportEveryNSteps=ExportEveryNSteps, ExportDepolarizationTime=ExportDepolarizationTime, ExportDepolarizationTimeOnce=ExportDepolarizationTimeOnce, ExportAPD=ExportAPD, ExportElapsedTime=ExportElapsedTime, ExportEc=ExportEc, ExportE1d=ExportE1d, ExportSigmaC=ExportSigmaC, ExportScale=ExportScale, Potential=Potential, Points=Points, Edges=Edges, Triangles=Triangles, Quads=Quads, Tetras=Tetras, Hexas=Hexas, RightVolume=RightVolume, LeftVolume=LeftVolume, RightPressurePv=RightPressurePv, LeftPressurePv=LeftPressurePv, RightPressurePat=RightPressurePat, LeftPressurePat=LeftPressurePat, RightPressurePar=RightPressurePar, LeftPressurePar=LeftPressurePar, RightFlowQ=RightFlowQ, LeftFlowQ=LeftFlowQ, APD90=APD90, stopDepolarizationTime=stopDepolarizationTime)
    return "CardiacSimulationExporter", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GenericConstraintSolver

.. autofunction:: GenericConstraintSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GenericConstraintSolver(self, maxIterations=None, tolerance=None, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, displayTime=None, sor=None, scaleTolerance=None, allVerified=None, schemeCorrection=None, unbuilt=None, computeGraphs=None, graphErrors=None, graphConstraints=None, graphForces=None, graphViolations=None, currentNumConstraints=None, currentNumConstraintGroups=None, currentIterations=None, currentError=None, reverseAccumulateOrder=None, constraintForces=None, computeConstraintForces=None, **kwargs):
    """
    A Generic Constraint Solver using the Linear Complementarity Problem formulation to solve Constraint based components


    :param name: object name  Default value: GenericConstraintSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param displayTime: Display time for each important step of GenericConstraintSolver.  Default value: 0

    :param maxIterations: maximal number of iterations of the Gauss-Seidel algorithm  Default value: 1000

    :param tolerance: residual error threshold for termination of the Gauss-Seidel algorithm  Default value: 0.001

    :param sor: Successive Over Relaxation parameter (0-2)  Default value: 1.0

    :param scaleTolerance: Scale the error tolerance with the number of constraints  Default value: 1

    :param allVerified: All contraints must be verified (each constraint's error < tolerance)  Default value: 0

    :param schemeCorrection: Apply new scheme where compliance is progressively corrected  Default value: 0

    :param unbuilt: Compliance is not fully built  Default value: 0

    :param computeGraphs: Compute graphs of errors and forces during resolution  Default value: 0

    :param graphErrors: Sum of the constraints' errors at each iteration  Default value: 

    :param graphConstraints: Graph of each constraint's error at the end of the resolution  Default value: 

    :param graphForces: Graph of each constraint's force at each step of the resolution  Default value: 

    :param graphViolations: Graph of each constraint's violation at each step of the resolution  Default value: 

    :param currentNumConstraints: OUTPUT: current number of constraints  Default value: 0

    :param currentNumConstraintGroups: OUTPUT: current number of constraints  Default value: 0

    :param currentIterations: OUTPUT: current number of constraint groups  Default value: 0

    :param currentError: OUTPUT: current error  Default value: 0.0

    :param reverseAccumulateOrder: True to accumulate constraints from nodes in reversed order (can be necessary when using multi-mappings or interaction constraints not following the node hierarchy)  Default value: 0

    :param constraintForces: OUTPUT: constraint forces (stored only if computeConstraintForces=True)  Default value: []

    :param computeConstraintForces: enable the storage of the constraintForces (default = False).  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, displayTime=displayTime, maxIterations=maxIterations, tolerance=tolerance, sor=sor, scaleTolerance=scaleTolerance, allVerified=allVerified, schemeCorrection=schemeCorrection, unbuilt=unbuilt, computeGraphs=computeGraphs, graphErrors=graphErrors, graphConstraints=graphConstraints, graphForces=graphForces, graphViolations=graphViolations, currentNumConstraints=currentNumConstraints, currentNumConstraintGroups=currentNumConstraintGroups, currentIterations=currentIterations, currentError=currentError, reverseAccumulateOrder=reverseAccumulateOrder, constraintForces=constraintForces, computeConstraintForces=computeConstraintForces)
    return "GenericConstraintSolver", params



# -*- coding: utf-8 -*-


"""
Module MechanicalState

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    MechanicalObject



Content:
========

.. automodule::

    MechanicalObject



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['MechanicalObject']
class MechanicalState:
    from .MechanicalObject import MechanicalObject



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GroupFilterYoungModulus

.. autofunction:: GroupFilterYoungModulus

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GroupFilterYoungModulus(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, groups=None, primitives=None, elementsGroup=None, youngModulus=None, mapGroupModulus=None, defaultYoungModulus=None, groupModulus=None, **kwargs):
    """
    This class gives a vector of young modulus according of a list of defined groups


    :param name: object name  Default value: GroupFilterYoungModulus

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param groups: Groups  Default value: 

    :param primitives: Vector of primitives (indices)  Default value: []

    :param elementsGroup: Vector of groups (each element gives its group  Default value: []

    :param youngModulus: Vector of young modulus for each primitive  Default value: []

    :param mapGroupModulus: Mapping between groups and modulus  Default value: 

    :param defaultYoungModulus: Default value if the primitive is not in a group  Default value: 10000.0

    :param groupModulus: list of young modulus for each group  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, groups=groups, primitives=primitives, elementsGroup=elementsGroup, youngModulus=youngModulus, mapGroupModulus=mapGroupModulus, defaultYoungModulus=defaultYoungModulus, groupModulus=groupModulus)
    return "GroupFilterYoungModulus", params



# -*- coding: utf-8 -*-


"""
Module CollisionAlgorithm

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    DirectSAP

    IncrSAP

    DefaultCollisionGroupManager

    DiscreteIntersection

    NewProximityIntersection

    MinProximityIntersection

    RayTraceDetection

    BruteForceDetection

    LMDNewProximityIntersection

    LocalMinDistance

    DefaultPipeline

    RuleBasedContactManager

    DefaultContactManager



Content:
========

.. automodule::

    DirectSAP

    IncrSAP

    DefaultCollisionGroupManager

    DiscreteIntersection

    NewProximityIntersection

    MinProximityIntersection

    RayTraceDetection

    BruteForceDetection

    LMDNewProximityIntersection

    LocalMinDistance

    DefaultPipeline

    RuleBasedContactManager

    DefaultContactManager



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['DirectSAP', 'IncrSAP', 'DefaultCollisionGroupManager', 'DiscreteIntersection', 'NewProximityIntersection', 'MinProximityIntersection', 'RayTraceDetection', 'BruteForceDetection', 'LMDNewProximityIntersection', 'LocalMinDistance', 'DefaultPipeline', 'RuleBasedContactManager', 'DefaultContactManager']
class CollisionAlgorithm:
    from .DirectSAP import DirectSAP
    from .IncrSAP import IncrSAP
    from .DefaultCollisionGroupManager import DefaultCollisionGroupManager
    from .DiscreteIntersection import DiscreteIntersection
    from .NewProximityIntersection import NewProximityIntersection
    from .MinProximityIntersection import MinProximityIntersection
    from .RayTraceDetection import RayTraceDetection
    from .BruteForceDetection import BruteForceDetection
    from .LMDNewProximityIntersection import LMDNewProximityIntersection
    from .LocalMinDistance import LocalMinDistance
    from .DefaultPipeline import DefaultPipeline
    from .RuleBasedContactManager import RuleBasedContactManager
    from .DefaultContactManager import DefaultContactManager



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component OglGrid

.. autofunction:: OglGrid

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def OglGrid(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, plane=None, size=None, nbSubdiv=None, color=None, thickness=None, draw=None, **kwargs):
    """
    Display a simple grid


    :param name: object name  Default value: OglGrid

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param plane: Plane of the grid  Default value: z

    :param size: Size of the squared grid  Default value: 10.0

    :param nbSubdiv: Number of subdivisions  Default value: 16

    :param color: Color of the lines in the grid. default=(0.34,0.34,0.34,1.0)  Default value: [[0.34117648005485535, 0.34117648005485535, 0.34117648005485535, 1.0]]

    :param thickness: Thickness of the lines in the grid  Default value: 1.0

    :param draw: Display the grid or not  Default value: 1


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, plane=plane, size=size, nbSubdiv=nbSubdiv, color=color, thickness=thickness, draw=draw)
    return "OglGrid", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component BeamFEMForceField

.. autofunction:: BeamFEMForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def BeamFEMForceField(self, **kwargs):
    """
    Beam finite elements



    """
    params = dict()
    return "BeamFEMForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component ArticulatedSystemMapping

.. autofunction:: ArticulatedSystemMapping

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def ArticulatedSystemMapping(self, **kwargs):
    """
    Mapping between a set of 6D DOF's and a set of angles (µ) using an articulated hierarchy container. 



    """
    params = dict()
    return "ArticulatedSystemMapping", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MechanicalMatrixMapper

.. autofunction:: MechanicalMatrixMapper

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MechanicalMatrixMapper(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, forceFieldList=None, stopAtNodeToParse=None, skipJ1tKJ1=None, skipJ2tKJ2=None, **kwargs):
    """
    This component allows to map the stiffness (and mass) matrix through a mapping.


    :param name: object name  Default value: MechanicalMatrixMapper

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param forceFieldList: List of ForceField Names to work on (by default will take all)  Default value: []

    :param stopAtNodeToParse: Boolean to choose whether forceFields in children Nodes of NodeToParse should be considered.  Default value: 0

    :param skipJ1tKJ1: Boolean to choose whether to skip J1tKJ1 to avoid 2 contributions, in case 2 MechanicalMatrixMapper are used  Default value: 0

    :param skipJ2tKJ2: Boolean to choose whether to skip J2tKJ2 to avoid 2 contributions, in case 2 MechanicalMatrixMapper are used  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, forceFieldList=forceFieldList, stopAtNodeToParse=stopAtNodeToParse, skipJ1tKJ1=skipJ1tKJ1, skipJ2tKJ2=skipJ2tKJ2)
    return "MechanicalMatrixMapper", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PrecomputedConstraintCorrection

.. autofunction:: PrecomputedConstraintCorrection

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PrecomputedConstraintCorrection(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, rotations=None, restDeformations=None, recompute=None, debugViewFrameScale=None, fileCompliance=None, fileDir=None, **kwargs):
    """
    Component computing constraint forces within a simulated body using the compliance method.


    :param name: object name  Default value: PrecomputedConstraintCorrection

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param rotations: (No help available)  Default value: 0

    :param restDeformations: (No help available)  Default value: 0

    :param recompute: if true, always recompute the compliance  Default value: 0

    :param debugViewFrameScale: Scale on computed node's frame  Default value: 1.0

    :param fileCompliance: Precomputed compliance matrix data file  Default value: 

    :param fileDir: If not empty, the compliance will be saved in this repertory  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, rotations=rotations, restDeformations=restDeformations, recompute=recompute, debugViewFrameScale=debugViewFrameScale, fileCompliance=fileCompliance, fileDir=fileDir)
    return "PrecomputedConstraintCorrection", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PointSplatModel

.. autofunction:: PointSplatModel

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PointSplatModel(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, radius=None, textureSize=None, alpha=None, color=None, pointData=None, **kwargs):
    """
    A simple visualization for a cloud of points.


    :param name: object name  Default value: PointSplatModel

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param radius: Radius of the spheres.  Default value: 1.0

    :param textureSize: Size of the billboard texture.  Default value: 32

    :param alpha: Opacity of the billboards. 1.0 is 100% opaque.  Default value: 1.0

    :param color: Billboard color.(default=[1.0,1.0,1.0,1.0])  Default value: [[1.0, 1.0, 1.0, 1.0]]

    :param pointData: scalar field modulating point colors  Default value: []


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, radius=radius, textureSize=textureSize, alpha=alpha, color=color, pointData=pointData)
    return "PointSplatModel", params



# -*- coding: utf-8 -*-


"""
Module Mass

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    HexahedralFEMForceFieldAndMass

    UniformMass

    MeshMatrixMass

    NonUniformHexahedronFEMForceFieldAndMass

    HexahedronFEMForceFieldAndMass

    HexahedronCompositeFEMForceFieldAndMass

    DiagonalMass

    NonUniformHexahedralFEMForceFieldAndMass



Content:
========

.. automodule::

    HexahedralFEMForceFieldAndMass

    UniformMass

    MeshMatrixMass

    NonUniformHexahedronFEMForceFieldAndMass

    HexahedronFEMForceFieldAndMass

    HexahedronCompositeFEMForceFieldAndMass

    DiagonalMass

    NonUniformHexahedralFEMForceFieldAndMass



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['HexahedralFEMForceFieldAndMass', 'UniformMass', 'MeshMatrixMass', 'NonUniformHexahedronFEMForceFieldAndMass', 'HexahedronFEMForceFieldAndMass', 'HexahedronCompositeFEMForceFieldAndMass', 'DiagonalMass', 'NonUniformHexahedralFEMForceFieldAndMass']
class Mass:
    from .HexahedralFEMForceFieldAndMass import HexahedralFEMForceFieldAndMass
    from .UniformMass import UniformMass
    from .MeshMatrixMass import MeshMatrixMass
    from .NonUniformHexahedronFEMForceFieldAndMass import NonUniformHexahedronFEMForceFieldAndMass
    from .HexahedronFEMForceFieldAndMass import HexahedronFEMForceFieldAndMass
    from .HexahedronCompositeFEMForceFieldAndMass import HexahedronCompositeFEMForceFieldAndMass
    from .DiagonalMass import DiagonalMass
    from .NonUniformHexahedralFEMForceFieldAndMass import NonUniformHexahedralFEMForceFieldAndMass



# -*- coding: utf-8 -*-


"""
Module Miscellaneous

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    EvalSurfaceDistance

    ArticulatedHierarchyContainer

    RequiredPlugin

    MessageHandlerComponent

    TriangleLocalMinDistanceFilter

    Camera

    CompareState

    PlasticMaterial

    DataController

    InteractiveCamera

    LineLocalMinDistanceFilter

    ExtraMonitor

    InfoComponent

    ShepardShapeFunction

    WriteTopology

    BarycentricShapeFunction

    RecordedCamera

    AddPluginRepository

    DataMonitor

    FileMessageHandlerComponent

    MappedObject

    Articulation

    PauseAnimationOnEvent

    HatShapeFunction

    SleepController

    WriteState

    ReadState

    MakeAlias

    MakeDataAlias

    ReadTopology

    APIVersion

    MeshTetraStuffing

    BlenderExporter

    OglShaderDefineMacro

    Monitor

    TopologicalChangeProcessor

    ArticulationCenter

    CardiacSimulationExporter

    TopologyVisualisation

    DevMonitorManager

    VTKExporter

    EvalPointsDistance

    MeshExporter

    AddDataRepository

    InputEventReader

    STLExporter

    PointLocalMinDistanceFilter

    OBJExporter



Content:
========

.. automodule::

    EvalSurfaceDistance

    ArticulatedHierarchyContainer

    RequiredPlugin

    MessageHandlerComponent

    TriangleLocalMinDistanceFilter

    Camera

    CompareState

    PlasticMaterial

    DataController

    InteractiveCamera

    LineLocalMinDistanceFilter

    ExtraMonitor

    InfoComponent

    ShepardShapeFunction

    WriteTopology

    BarycentricShapeFunction

    RecordedCamera

    AddPluginRepository

    DataMonitor

    FileMessageHandlerComponent

    MappedObject

    Articulation

    PauseAnimationOnEvent

    HatShapeFunction

    SleepController

    WriteState

    ReadState

    MakeAlias

    MakeDataAlias

    ReadTopology

    APIVersion

    MeshTetraStuffing

    BlenderExporter

    OglShaderDefineMacro

    Monitor

    TopologicalChangeProcessor

    ArticulationCenter

    CardiacSimulationExporter

    TopologyVisualisation

    DevMonitorManager

    VTKExporter

    EvalPointsDistance

    MeshExporter

    AddDataRepository

    InputEventReader

    STLExporter

    PointLocalMinDistanceFilter

    OBJExporter



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['EvalSurfaceDistance', 'ArticulatedHierarchyContainer', 'RequiredPlugin', 'MessageHandlerComponent', 'TriangleLocalMinDistanceFilter', 'Camera', 'CompareState', 'PlasticMaterial', 'DataController', 'InteractiveCamera', 'LineLocalMinDistanceFilter', 'ExtraMonitor', 'InfoComponent', 'ShepardShapeFunction', 'WriteTopology', 'BarycentricShapeFunction', 'RecordedCamera', 'AddPluginRepository', 'DataMonitor', 'FileMessageHandlerComponent', 'MappedObject', 'Articulation', 'PauseAnimationOnEvent', 'HatShapeFunction', 'SleepController', 'WriteState', 'ReadState', 'MakeAlias', 'MakeDataAlias', 'ReadTopology', 'APIVersion', 'MeshTetraStuffing', 'BlenderExporter', 'OglShaderDefineMacro', 'Monitor', 'TopologicalChangeProcessor', 'ArticulationCenter', 'CardiacSimulationExporter', 'TopologyVisualisation', 'DevMonitorManager', 'VTKExporter', 'EvalPointsDistance', 'MeshExporter', 'AddDataRepository', 'InputEventReader', 'STLExporter', 'PointLocalMinDistanceFilter', 'OBJExporter']
class Miscellaneous:
    from .EvalSurfaceDistance import EvalSurfaceDistance
    from .ArticulatedHierarchyContainer import ArticulatedHierarchyContainer
    from .RequiredPlugin import RequiredPlugin
    from .MessageHandlerComponent import MessageHandlerComponent
    from .TriangleLocalMinDistanceFilter import TriangleLocalMinDistanceFilter
    from .Camera import Camera
    from .CompareState import CompareState
    from .PlasticMaterial import PlasticMaterial
    from .DataController import DataController
    from .InteractiveCamera import InteractiveCamera
    from .LineLocalMinDistanceFilter import LineLocalMinDistanceFilter
    from .ExtraMonitor import ExtraMonitor
    from .InfoComponent import InfoComponent
    from .ShepardShapeFunction import ShepardShapeFunction
    from .WriteTopology import WriteTopology
    from .BarycentricShapeFunction import BarycentricShapeFunction
    from .RecordedCamera import RecordedCamera
    from .AddPluginRepository import AddPluginRepository
    from .DataMonitor import DataMonitor
    from .FileMessageHandlerComponent import FileMessageHandlerComponent
    from .MappedObject import MappedObject
    from .Articulation import Articulation
    from .PauseAnimationOnEvent import PauseAnimationOnEvent
    from .HatShapeFunction import HatShapeFunction
    from .SleepController import SleepController
    from .WriteState import WriteState
    from .ReadState import ReadState
    from .MakeAlias import MakeAlias
    from .MakeDataAlias import MakeDataAlias
    from .ReadTopology import ReadTopology
    from .APIVersion import APIVersion
    from .MeshTetraStuffing import MeshTetraStuffing
    from .BlenderExporter import BlenderExporter
    from .OglShaderDefineMacro import OglShaderDefineMacro
    from .Monitor import Monitor
    from .TopologicalChangeProcessor import TopologicalChangeProcessor
    from .ArticulationCenter import ArticulationCenter
    from .CardiacSimulationExporter import CardiacSimulationExporter
    from .TopologyVisualisation import TopologyVisualisation
    from .DevMonitorManager import DevMonitorManager
    from .VTKExporter import VTKExporter
    from .EvalPointsDistance import EvalPointsDistance
    from .MeshExporter import MeshExporter
    from .AddDataRepository import AddDataRepository
    from .InputEventReader import InputEventReader
    from .STLExporter import STLExporter
    from .PointLocalMinDistanceFilter import PointLocalMinDistanceFilter
    from .OBJExporter import OBJExporter



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component GridTopology

.. autofunction:: GridTopology

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def GridTopology(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, filename=None, position=None, edges=None, triangles=None, quads=None, tetrahedra=None, hexahedra=None, uv=None, drawEdges=None, drawTriangles=None, drawQuads=None, drawTetrahedra=None, drawHexahedra=None, n=None, computeHexaList=None, computeQuadList=None, computeTriangleList=None, computeEdgeList=None, computePointList=None, createTexCoords=None, **kwargs):
    """
    Base class fo a regular grid in 3D


    :param name: object name  Default value: GridTopology

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param filename: Filename of the mesh  Default value: 

    :param position: List of point positions  Default value: []

    :param edges: List of edge indices  Default value: [[1, 3], [3, 0], [0, 1], [3, 2], [2, 0], [5, 7], [7, 4], [4, 5], [7, 6], [6, 4], [1, 5], [5, 0], [4, 0], [3, 7], [7, 2], [6, 2], [6, 0], [7, 1]]

    :param triangles: List of triangle indices  Default value: [[0, 1, 3], [0, 3, 2], [4, 5, 7], [4, 7, 6], [0, 1, 5], [0, 5, 4], [2, 3, 7], [2, 7, 6], [0, 2, 6], [0, 6, 4], [1, 3, 7], [1, 7, 5]]

    :param quads: List of quad indices  Default value: [[0, 1, 3, 2], [4, 5, 7, 6], [0, 1, 5, 4], [2, 3, 7, 6], [0, 2, 6, 4], [1, 3, 7, 5]]

    :param tetrahedra: List of tetrahedron indices  Default value: []

    :param hexahedra: List of hexahedron indices  Default value: [[0, 1, 3, 2, 4, 5, 7, 6]]

    :param uv: List of uv coordinates  Default value: []

    :param drawEdges: if true, draw the topology Edges  Default value: 0

    :param drawTriangles: if true, draw the topology Triangles  Default value: 0

    :param drawQuads: if true, draw the topology Quads  Default value: 0

    :param drawTetrahedra: if true, draw the topology Tetrahedra  Default value: 0

    :param drawHexahedra: if true, draw the topology hexahedra  Default value: 0

    :param n: grid resolution. (default = 2 2 2)  Default value: [[2, 2, 2]]

    :param computeHexaList: put true if the list of Hexahedra is needed during init (default=true)  Default value: 1

    :param computeQuadList: put true if the list of Quad is needed during init (default=true)  Default value: 1

    :param computeTriangleList: put true if the list of triangle is needed during init (default=true)  Default value: 1

    :param computeEdgeList: put true if the list of Lines is needed during init (default=true)  Default value: 1

    :param computePointList: put true if the list of Points is needed during init (default=true)  Default value: 1

    :param createTexCoords: If set to true, virtual texture coordinates will be generated using 3D interpolation (default=false).  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, filename=filename, position=position, edges=edges, triangles=triangles, quads=quads, tetrahedra=tetrahedra, hexahedra=hexahedra, uv=uv, drawEdges=drawEdges, drawTriangles=drawTriangles, drawQuads=drawQuads, drawTetrahedra=drawTetrahedra, drawHexahedra=drawHexahedra, n=n, computeHexaList=computeHexaList, computeQuadList=computeQuadList, computeTriangleList=computeTriangleList, computeEdgeList=computeEdgeList, computePointList=computePointList, createTexCoords=createTexCoords)
    return "GridTopology", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component AngularSpringForceField

.. autofunction:: AngularSpringForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def AngularSpringForceField(self, **kwargs):
    """
    Angular springs applied to rotational degrees of freedom of a rigid body or frame



    """
    params = dict()
    return "AngularSpringForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component MergeROIs

.. autofunction:: MergeROIs

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def MergeROIs(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, nbROIs=None, roiIndices=None, **kwargs):
    """
    Merge a list of ROIs (vector<Indices>) into a single Data (vector<svector<Indices>>)


    :param name: object name  Default value: MergeROIs

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param nbROIs: size of indices/value vector  Default value: 0

    :param roiIndices: Vector of ROIs  Default value: 


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, nbROIs=nbROIs, roiIndices=roiIndices)
    return "MergeROIs", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component PlaneForceField

.. autofunction:: PlaneForceField

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def PlaneForceField(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, isCompliance=None, rayleighStiffness=None, normal=None, d=None, stiffness=None, damping=None, maxForce=None, bilateral=None, localRange=None, showPlane=None, planeColor=None, showPlaneSize=None, **kwargs):
    """
    Repulsion applied by a plane toward the exterior (half-space)


    :param name: object name  Default value: PlaneForceField

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param isCompliance: Consider the component as a compliance, else as a stiffness  Default value: 0

    :param rayleighStiffness: Rayleigh damping - stiffness matrix coefficient  Default value: 0.0

    :param normal: plane normal. (default=[0,1,0])  Default value: [[0.0, 1.0, 0.0]]

    :param d: plane d coef. (default=0)  Default value: 0.0

    :param stiffness: force stiffness. (default=500)  Default value: 500.0

    :param damping: force damping. (default=5)  Default value: 5.0

    :param maxForce: if non-null , the max force that can be applied to the object. (default=0)  Default value: 0.0

    :param bilateral: if true the plane force field is applied on both sides. (default=false)  Default value: 0

    :param localRange: optional range of local DOF indices. Any computation involving indices outside of this range are discarded (useful for parallelization using mesh partitionning)  Default value: [[-1, -1]]

    :param showPlane: enable/disable drawing of plane. (default=false)  Default value: 0

    :param planeColor: plane color. (default=[0.0,0.5,0.2,1.0])  Default value: [[0.0, 0.5, 0.20000000298023224, 1.0]]

    :param showPlaneSize: plane display size if draw is enabled. (default=10)  Default value: 10.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, isCompliance=isCompliance, rayleighStiffness=rayleighStiffness, normal=normal, d=d, stiffness=stiffness, damping=damping, maxForce=maxForce, bilateral=bilateral, localRange=localRange, showPlane=showPlane, planeColor=planeColor, showPlaneSize=showPlaneSize)
    return "PlaneForceField", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component StaticSolver

.. autofunction:: StaticSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def StaticSolver(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, newton_iterations=None, correction_tolerance_threshold=None, residual_tolerance_threshold=None, should_diverge_when_residual_is_growing=None, **kwargs):
    """
    Static ODE Solver


    :param name: object name  Default value: StaticSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param newton_iterations: Number of newton iterations between each load increments (normally, one load increment per simulation time-step.  Default value: 1

    :param correction_tolerance_threshold: Convergence criterion: The newton iterations will stop when the norm of correction |du| reach this threshold.  Default value: 1e-05

    :param residual_tolerance_threshold: Convergence criterion: The newton iterations will stop when the norm of the residual |f - K(u)| reach this threshold. Use a negative value to disable this criterion.  Default value: 1e-05

    :param should_diverge_when_residual_is_growing: Divergence criterion: The newton iterations will stop when the residual is greater than the one from the previous iteration.  Default value: 0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, newton_iterations=newton_iterations, correction_tolerance_threshold=correction_tolerance_threshold, residual_tolerance_threshold=residual_tolerance_threshold, should_diverge_when_residual_is_growing=should_diverge_when_residual_is_growing)
    return "StaticSolver", params



# -*- coding: utf-8 -*-

from sofacomponents.lib.base_component import sofa_component


"""
Component SVDLinearSolver

.. autofunction:: SVDLinearSolver

Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""


@sofa_component
def SVDLinearSolver(self, name=None, printLog=None, tags=None, bbox=None, componentState=None, listening=None, verbose=None, minSingularValue=None, conditionNumber=None, **kwargs):
    """
    Linear system solver using the conjugate gradient iterative algorithm


    :param name: object name  Default value: SVDLinearSolver

    :param printLog: if true, emits extra messages at runtime.  Default value: 0

    :param tags: list of the subsets the objet belongs to  Default value: []

    :param bbox: this object bounding box  Default value: [[1.7976931348623157e+308, 1.7976931348623157e+308, 1.7976931348623157e+308], [-1.7976931348623157e+308, -1.7976931348623157e+308, -1.7976931348623157e+308]]

    :param componentState: The state of the component among (Dirty, Valid, Undefined, Loading, Invalid).  Default value: Undefined

    :param listening: if true, handle the events, otherwise ignore the events  Default value: 0

    :param verbose: Dump system state at each iteration  Default value: 0

    :param minSingularValue: Thershold under which a singular value is set to 0, for the stabilization of ill-conditioned system.  Default value: 1e-06

    :param conditionNumber: Condition number of the matrix: ratio between the largest and smallest singular values. Computed in method solve.  Default value: 0.0


    """
    params = dict(name=name, printLog=printLog, tags=tags, bbox=bbox, componentState=componentState, listening=listening, verbose=verbose, minSingularValue=minSingularValue, conditionNumber=conditionNumber)
    return "SVDLinearSolver", params



# -*- coding: utf-8 -*-


"""
Module ConstraintSolver

Content of the module
**********************

Summary:
========
.. autosummary::
     :toctree: _autosummary

    LMConstraintSolver

    LCPConstraintSolver

    PrecomputedConstraintCorrection

    LinearSolverConstraintCorrection

    LMConstraintDirectSolver

    GenericConstraintSolver

    GenericConstraintCorrection

    UncoupledConstraintCorrection



Content:
========

.. automodule::

    LMConstraintSolver

    LCPConstraintSolver

    PrecomputedConstraintCorrection

    LinearSolverConstraintCorrection

    LMConstraintDirectSolver

    GenericConstraintSolver

    GenericConstraintCorrection

    UncoupledConstraintCorrection



Indices and tables
******************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
"""
# __all__=['LMConstraintSolver', 'LCPConstraintSolver', 'PrecomputedConstraintCorrection', 'LinearSolverConstraintCorrection', 'LMConstraintDirectSolver', 'GenericConstraintSolver', 'GenericConstraintCorrection', 'UncoupledConstraintCorrection']
class ConstraintSolver:
    from .LMConstraintSolver import LMConstraintSolver
    from .LCPConstraintSolver import LCPConstraintSolver
    from .PrecomputedConstraintCorrection import PrecomputedConstraintCorrection
    from .LinearSolverConstraintCorrection import LinearSolverConstraintCorrection
    from .LMConstraintDirectSolver import LMConstraintDirectSolver
    from .GenericConstraintSolver import GenericConstraintSolver
    from .GenericConstraintCorrection import GenericConstraintCorrection
    from .UncoupledConstraintCorrection import UncoupledConstraintCorrection
